@@ -11,7 +11,7 @@
 
 #include "test_suite.h"
 
-test_suite_t ctrl_diagram_controller_test_get_list(void);
+test_suite_t ctrl_diagram_controller_test_get_suite(void);
 
 #endif  /* CTRL_DIAGRAM_CONTROLLER_TEST_H */
 
