@@ -11,7 +11,7 @@
 
 #include "test_suite.h"
 
-test_suite_t ctrl_undo_redo_list_test_get_list(void);
+test_suite_t ctrl_undo_redo_list_test_get_suite(void);
 
 #endif  /* CTRL_UNDO_REDO_LIST_TEST_H */
 
