@@ -12,7 +12,7 @@
  */
 
 #include "data_diagram.h"
-#include "data_error.h"
+#include "u8/u8_error.h"
 #include "data_classifier.h"
 #include "data_diagramelement.h"
 #include "data_feature.h"
@@ -63,18 +63,18 @@ static inline char* data_database_sql_builder_get_string_ptr ( data_database_sql
  *
  *  \param this_ pointer to own object attributes
  *  \param diagram diagram to be created. The id should be DATA_ROW_ID_VOID unless a diagram with known, unique id shall be created.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_create_diagram_command ( data_database_sql_builder_t *this_, const data_diagram_t *diagram );
+u8_error_t data_database_sql_builder_build_create_diagram_command ( data_database_sql_builder_t *this_, const data_diagram_t *diagram );
 
 /*!
  *  \brief builds the sql command string to delete a diagram record. The result is stored in (*this_).private_sql_stringbuf.
  *
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be deleted
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_delete_diagram_command ( data_database_sql_builder_t *this_, data_row_id_t diagram_id );
+u8_error_t data_database_sql_builder_build_delete_diagram_command ( data_database_sql_builder_t *this_, data_row_id_t diagram_id );
 
 /*!
  *  \brief builds the sql command string to update a diagram record. The result is stored in (*this_).private_sql_stringbuf.
@@ -82,9 +82,9 @@ data_error_t data_database_sql_builder_build_delete_diagram_command ( data_datab
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_name new name of the diagram
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagram_name_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, const char *new_diagram_name );
+u8_error_t data_database_sql_builder_build_update_diagram_name_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, const char *new_diagram_name );
 
 /*!
  *  \brief builds the sql command string to update a diagram record. The result is stored in (*this_).private_sql_stringbuf.
@@ -92,9 +92,9 @@ data_error_t data_database_sql_builder_build_update_diagram_name_cmd ( data_data
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_description new description of the diagram
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagram_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, const char *new_diagram_description );
+u8_error_t data_database_sql_builder_build_update_diagram_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, const char *new_diagram_description );
 
 /*!
  *  \brief builds the sql command string to update a diagram record. The result is stored in (*this_).private_sql_stringbuf.
@@ -102,9 +102,9 @@ data_error_t data_database_sql_builder_build_update_diagram_description_cmd ( da
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_type new type of the diagram
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagram_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, data_diagram_type_t new_diagram_type );
+u8_error_t data_database_sql_builder_build_update_diagram_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, data_diagram_type_t new_diagram_type );
 
 /*!
  *  \brief builds the sql command string to update a diagram record. The result is stored in (*this_).private_sql_stringbuf.
@@ -112,9 +112,9 @@ data_error_t data_database_sql_builder_build_update_diagram_type_cmd ( data_data
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_list_order new list_order of the diagram
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagram_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, int32_t new_diagram_list_order );
+u8_error_t data_database_sql_builder_build_update_diagram_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, int32_t new_diagram_list_order );
 
 /*!
  *  \brief builds the sql command string to update a diagram record. The result is stored in (*this_).private_sql_stringbuf.
@@ -122,9 +122,9 @@ data_error_t data_database_sql_builder_build_update_diagram_list_order_cmd ( dat
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_parent_id new parent_id of the diagram
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagram_parent_id_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, data_row_id_t new_diagram_parent_id );
+u8_error_t data_database_sql_builder_build_update_diagram_parent_id_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagram_id, data_row_id_t new_diagram_parent_id );
 
 /* ================================ CLASSIFIER ================================ */
 
@@ -133,9 +133,9 @@ data_error_t data_database_sql_builder_build_update_diagram_parent_id_cmd ( data
  *
  *  \param this_ pointer to own object attributes
  *  \param classifier classifier to be created. The id should be DATA_ROW_ID_VOID unless a classifier with known, unique id shall be created.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_create_classifier_command ( data_database_sql_builder_t *this_, const data_classifier_t *classifier );
+u8_error_t data_database_sql_builder_build_create_classifier_command ( data_database_sql_builder_t *this_, const data_classifier_t *classifier );
 
 /*!
  *  \brief builds the sql command string to delete a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -143,7 +143,7 @@ data_error_t data_database_sql_builder_build_create_classifier_command ( data_da
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be deleted
  */
-data_error_t data_database_sql_builder_build_delete_classifier_command ( data_database_sql_builder_t *this_, data_row_id_t classifier_id );
+u8_error_t data_database_sql_builder_build_delete_classifier_command ( data_database_sql_builder_t *this_, data_row_id_t classifier_id );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -152,7 +152,7 @@ data_error_t data_database_sql_builder_build_delete_classifier_command ( data_da
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_stereotype new stereotype of the classifier
  */
-data_error_t data_database_sql_builder_build_update_classifier_stereotype_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, const char *new_classifier_stereotype );
+u8_error_t data_database_sql_builder_build_update_classifier_stereotype_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, const char *new_classifier_stereotype );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -160,9 +160,9 @@ data_error_t data_database_sql_builder_build_update_classifier_stereotype_cmd (
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_name new name of the classifier
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_classifier_name_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, const char *new_classifier_name );
+u8_error_t data_database_sql_builder_build_update_classifier_name_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, const char *new_classifier_name );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -170,9 +170,9 @@ data_error_t data_database_sql_builder_build_update_classifier_name_cmd ( data_d
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_description new description of the classifier
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_classifier_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, const char *new_classifier_description );
+u8_error_t data_database_sql_builder_build_update_classifier_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, const char *new_classifier_description );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -180,9 +180,9 @@ data_error_t data_database_sql_builder_build_update_classifier_description_cmd (
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_main_type new description of the classifier
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_classifier_main_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, data_classifier_type_t new_classifier_main_type );
+u8_error_t data_database_sql_builder_build_update_classifier_main_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, data_classifier_type_t new_classifier_main_type );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -190,9 +190,9 @@ data_error_t data_database_sql_builder_build_update_classifier_main_type_cmd ( d
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_x_order new x_order of the classifier
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_classifier_x_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, int32_t new_classifier_x_order );
+u8_error_t data_database_sql_builder_build_update_classifier_x_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, int32_t new_classifier_x_order );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -200,9 +200,9 @@ data_error_t data_database_sql_builder_build_update_classifier_x_order_cmd ( dat
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_y_order new y_order of the classifier
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_classifier_y_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, int32_t new_classifier_y_order );
+u8_error_t data_database_sql_builder_build_update_classifier_y_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, int32_t new_classifier_y_order );
 
 /*!
  *  \brief builds the sql command string to update a classifier record. The result is stored in (*this_).private_sql_stringbuf.
@@ -210,9 +210,9 @@ data_error_t data_database_sql_builder_build_update_classifier_y_order_cmd ( dat
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_list_order new list_order of the classifier
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_classifier_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, int32_t new_classifier_list_order );
+u8_error_t data_database_sql_builder_build_update_classifier_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t classifier_id, int32_t new_classifier_list_order );
 
 /* ================================ DIAGRAMELEMENT ================================ */
 
@@ -221,18 +221,18 @@ data_error_t data_database_sql_builder_build_update_classifier_list_order_cmd (
  *
  *  \param this_ pointer to own object attributes
  *  \param diagramelement diagramelement to be created. The id should be DATA_ROW_ID_VOID unless a diagramelement with known, unique id shall be created.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_create_diagramelement_command ( data_database_sql_builder_t *this_, const data_diagramelement_t *diagramelement );
+u8_error_t data_database_sql_builder_build_create_diagramelement_command ( data_database_sql_builder_t *this_, const data_diagramelement_t *diagramelement );
 
 /*!
  *  \brief builds the sql command string to delete a diagramelement record. The result is stored in (*this_).private_sql_stringbuf.
  *
  *  \param this_ pointer to own object attributes
  *  \param diagramelement_id id of the diagramelement to be deleted.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_delete_diagramelement_command ( data_database_sql_builder_t *this_, data_row_id_t diagramelement_id );
+u8_error_t data_database_sql_builder_build_delete_diagramelement_command ( data_database_sql_builder_t *this_, data_row_id_t diagramelement_id );
 
 /*!
  *  \brief builds the sql command string to update a diagramelement record. The result is stored in (*this_).private_sql_stringbuf.
@@ -240,9 +240,9 @@ data_error_t data_database_sql_builder_build_delete_diagramelement_command ( dat
  *  \param this_ pointer to own object attributes
  *  \param diagramelement_id id of the diagramelement to be updated
  *  \param new_display_flags new display_flags of the diagramelement
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagramelement_display_flags_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagramelement_id, data_diagramelement_flag_t new_display_flags );
+u8_error_t data_database_sql_builder_build_update_diagramelement_display_flags_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagramelement_id, data_diagramelement_flag_t new_display_flags );
 
 /*!
  *  \brief builds the sql command string to update a diagramelement record. The result is stored in (*this_).private_sql_stringbuf.
@@ -250,9 +250,9 @@ data_error_t data_database_sql_builder_build_update_diagramelement_display_flags
  *  \param this_ pointer to own object attributes
  *  \param diagramelement_id id of the diagramelement to be updated
  *  \param new_focused_feature_id new focused_feature_id of the diagramelement
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_diagramelement_focused_feature_id_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagramelement_id, data_row_id_t new_focused_feature_id );
+u8_error_t data_database_sql_builder_build_update_diagramelement_focused_feature_id_cmd ( data_database_sql_builder_t *this_, data_row_id_t diagramelement_id, data_row_id_t new_focused_feature_id );
 
 /* ================================ FEATURE ================================ */
 
@@ -261,18 +261,18 @@ data_error_t data_database_sql_builder_build_update_diagramelement_focused_featu
  *
  *  \param this_ pointer to own object attributes
  *  \param feature feature to be created. The id should be DATA_ROW_ID_VOID unless a feature with known, unique id shall be created.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_create_feature_command ( data_database_sql_builder_t *this_, const data_feature_t *feature );
+u8_error_t data_database_sql_builder_build_create_feature_command ( data_database_sql_builder_t *this_, const data_feature_t *feature );
 
 /*!
  *  \brief builds the sql command string to delete a feature record. The result is stored in (*this_).private_sql_stringbuf.
  *
  *  \param this_ pointer to own object attributes
  *  \param feature_id id of the feature to be deleted
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_delete_feature_command ( data_database_sql_builder_t *this_, data_row_id_t feature_id );
+u8_error_t data_database_sql_builder_build_delete_feature_command ( data_database_sql_builder_t *this_, data_row_id_t feature_id );
 
 /*!
  *  \brief builds the sql command string to update a feature record. The result is stored in (*this_).private_sql_stringbuf.
@@ -280,9 +280,9 @@ data_error_t data_database_sql_builder_build_delete_feature_command ( data_datab
  *  \param this_ pointer to own object attributes
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_type new type of the feature
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_feature_main_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, data_feature_type_t new_feature_type );
+u8_error_t data_database_sql_builder_build_update_feature_main_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, data_feature_type_t new_feature_type );
 
 /*!
  *  \brief builds the sql command string to update a feature record. The result is stored in (*this_).private_sql_stringbuf.
@@ -290,9 +290,9 @@ data_error_t data_database_sql_builder_build_update_feature_main_type_cmd ( data
  *  \param this_ pointer to own object attributes
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_key new key of the feature
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_feature_key_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, const char *new_feature_key );
+u8_error_t data_database_sql_builder_build_update_feature_key_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, const char *new_feature_key );
 
 /*!
  *  \brief builds the sql command string to update a feature record. The result is stored in (*this_).private_sql_stringbuf.
@@ -300,9 +300,9 @@ data_error_t data_database_sql_builder_build_update_feature_key_cmd ( data_datab
  *  \param this_ pointer to own object attributes
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_value new value of the feature
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_feature_value_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, const char *new_feature_value );
+u8_error_t data_database_sql_builder_build_update_feature_value_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, const char *new_feature_value );
 
 /*!
  *  \brief builds the sql command string to update a feature record. The result is stored in (*this_).private_sql_stringbuf.
@@ -310,9 +310,9 @@ data_error_t data_database_sql_builder_build_update_feature_value_cmd ( data_dat
  *  \param this_ pointer to own object attributes
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_description new description of the feature
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_feature_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, const char *new_feature_description );
+u8_error_t data_database_sql_builder_build_update_feature_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, const char *new_feature_description );
 
 /*!
  *  \brief builds the sql command string to update a feature record. The result is stored in (*this_).private_sql_stringbuf.
@@ -320,9 +320,9 @@ data_error_t data_database_sql_builder_build_update_feature_description_cmd ( da
  *  \param this_ pointer to own object attributes
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_list_order new list_order of the feature
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_feature_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, int32_t new_feature_list_order );
+u8_error_t data_database_sql_builder_build_update_feature_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t feature_id, int32_t new_feature_list_order );
 
 /* ================================ RELATIONSHIP ================================ */
 
@@ -331,18 +331,18 @@ data_error_t data_database_sql_builder_build_update_feature_list_order_cmd ( dat
  *
  *  \param this_ pointer to own object attributes
  *  \param relationship relationship to be created. The id should be DATA_ROW_ID_VOID unless a relationship with known, unique id shall be created.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_create_relationship_command ( data_database_sql_builder_t *this_, const data_relationship_t *relationship );
+u8_error_t data_database_sql_builder_build_create_relationship_command ( data_database_sql_builder_t *this_, const data_relationship_t *relationship );
 
 /*!
  *  \brief builds the sql command string to delete a relationship record. The result is stored in (*this_).private_sql_stringbuf.
  *
  *  \param this_ pointer to own object attributes
  *  \param relationship_id id of the relationship to be deleted
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_delete_relationship_command ( data_database_sql_builder_t *this_, data_row_id_t relationship_id );
+u8_error_t data_database_sql_builder_build_delete_relationship_command ( data_database_sql_builder_t *this_, data_row_id_t relationship_id );
 
 /*!
  *  \brief builds the sql command string to update a relationship record. The result is stored in (*this_).private_sql_stringbuf.
@@ -350,9 +350,9 @@ data_error_t data_database_sql_builder_build_delete_relationship_command ( data_
  *  \param this_ pointer to own object attributes
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_type new type of the relationship
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_relationship_main_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, data_relationship_type_t new_relationship_type );
+u8_error_t data_database_sql_builder_build_update_relationship_main_type_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, data_relationship_type_t new_relationship_type );
 
 /*!
  *  \brief builds the sql command string to update a relationship record. The result is stored in (*this_).private_sql_stringbuf.
@@ -360,9 +360,9 @@ data_error_t data_database_sql_builder_build_update_relationship_main_type_cmd (
  *  \param this_ pointer to own object attributes
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_name new name of the relationship
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_relationship_name_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, const char *new_relationship_name );
+u8_error_t data_database_sql_builder_build_update_relationship_name_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, const char *new_relationship_name );
 
 /*!
  *  \brief builds the sql command string to update a relationship record. The result is stored in (*this_).private_sql_stringbuf.
@@ -370,9 +370,9 @@ data_error_t data_database_sql_builder_build_update_relationship_name_cmd ( data
  *  \param this_ pointer to own object attributes
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_description new description of the relationship
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_relationship_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, const char *new_relationship_description );
+u8_error_t data_database_sql_builder_build_update_relationship_description_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, const char *new_relationship_description );
 
 /*!
  *  \brief builds the sql command string to update a relationship record. The result is stored in (*this_).private_sql_stringbuf.
@@ -380,9 +380,9 @@ data_error_t data_database_sql_builder_build_update_relationship_description_cmd
  *  \param this_ pointer to own object attributes
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_list_order new list_order of the relationship
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_sql_builder_build_update_relationship_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, int32_t new_relationship_list_order );
+u8_error_t data_database_sql_builder_build_update_relationship_list_order_cmd ( data_database_sql_builder_t *this_, data_row_id_t relationship_id, int32_t new_relationship_list_order );
 
 #include "storage/data_database_sql_builder.inl"
 
