@@ -17,7 +17,7 @@
 #include "storage/data_database_reader.h"
 #include "storage/data_database_sql_builder.h"
 #include "data_diagram.h"
-#include "data_error.h"
+#include "u8/u8_error.h"
 #include "data_classifier.h"
 #include "data_diagramelement.h"
 #include "data_feature.h"
@@ -75,9 +75,9 @@ void data_database_writer_db_change_callback ( data_database_writer_t *this_, da
  *  \param this_ pointer to own object attributes
  *  \param diagram data of the new diagram record to be created. The id should be DATA_ROW_ID_VOID unless a diagram with known, unique id shall be created.
  *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_create_diagram ( data_database_writer_t *this_, const data_diagram_t *diagram, data_row_id_t* out_new_id );
+u8_error_t data_database_writer_create_diagram ( data_database_writer_t *this_, const data_diagram_t *diagram, data_row_id_t* out_new_id );
 
 /*!
  *  \brief deletes a diagram record and returns its old data
@@ -87,9 +87,9 @@ data_error_t data_database_writer_create_diagram ( data_database_writer_t *this_
  *  \param this_ pointer to own object attributes
  *  \param obj_id id of the diagram record to be deleted.
  *  \param[out] out_old_diagram storage, where the contents of the deleted, old record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_delete_diagram ( data_database_writer_t *this_, data_row_id_t obj_id, data_diagram_t *out_old_diagram );
+u8_error_t data_database_writer_delete_diagram ( data_database_writer_t *this_, data_row_id_t obj_id, data_diagram_t *out_old_diagram );
 
 /*!
  *  \brief updates the diagram attribute: description
@@ -98,9 +98,9 @@ data_error_t data_database_writer_delete_diagram ( data_database_writer_t *this_
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_description new description text of the diagram
  *  \param[out] out_old_diagram storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagram_description ( data_database_writer_t *this_, data_row_id_t diagram_id, const char* new_diagram_description, data_diagram_t *out_old_diagram );
+u8_error_t data_database_writer_update_diagram_description ( data_database_writer_t *this_, data_row_id_t diagram_id, const char* new_diagram_description, data_diagram_t *out_old_diagram );
 
 /*!
  *  \brief updates the diagram attribute: name
@@ -109,9 +109,9 @@ data_error_t data_database_writer_update_diagram_description ( data_database_wri
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_name new name of the diagram
  *  \param[out] out_old_diagram storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagram_name ( data_database_writer_t *this_, data_row_id_t diagram_id, const char* new_diagram_name, data_diagram_t *out_old_diagram );
+u8_error_t data_database_writer_update_diagram_name ( data_database_writer_t *this_, data_row_id_t diagram_id, const char* new_diagram_name, data_diagram_t *out_old_diagram );
 
 /*!
  *  \brief updates the diagram attribute: diagram_type
@@ -120,9 +120,9 @@ data_error_t data_database_writer_update_diagram_name ( data_database_writer_t *
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_type new diagram_type of the diagram
  *  \param[out] out_old_diagram storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagram_type ( data_database_writer_t *this_, data_row_id_t diagram_id, data_diagram_type_t new_diagram_type, data_diagram_t *out_old_diagram );
+u8_error_t data_database_writer_update_diagram_type ( data_database_writer_t *this_, data_row_id_t diagram_id, data_diagram_type_t new_diagram_type, data_diagram_t *out_old_diagram );
 
 /*!
  *  \brief updates the diagram attribute: list_order
@@ -131,9 +131,9 @@ data_error_t data_database_writer_update_diagram_type ( data_database_writer_t *
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_list_order new list_order of the diagram
  *  \param[out] out_old_diagram storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagram_list_order ( data_database_writer_t *this_, data_row_id_t diagram_id, int32_t new_diagram_list_order, data_diagram_t *out_old_diagram );
+u8_error_t data_database_writer_update_diagram_list_order ( data_database_writer_t *this_, data_row_id_t diagram_id, int32_t new_diagram_list_order, data_diagram_t *out_old_diagram );
 
 /*!
  *  \brief updates the diagram attribute: parent_id
@@ -141,10 +141,11 @@ data_error_t data_database_writer_update_diagram_list_order ( data_database_writ
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagram to be updated
  *  \param new_diagram_parent_id new parent diagram id of the diagram
- *  \param[out] out_old_diagram storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \param[out] out_old_diagram storage, where the contents of the old, unmodified record is stored.
+ *                              NULL if old data shall not be returned.
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagram_parent_id ( data_database_writer_t *this_, data_row_id_t diagram_id, data_row_id_t new_diagram_parent_id, data_diagram_t *out_old_diagram );
+u8_error_t data_database_writer_update_diagram_parent_id ( data_database_writer_t *this_, data_row_id_t diagram_id, data_row_id_t new_diagram_parent_id, data_diagram_t *out_old_diagram );
 
 /* ================================ CLASSIFIER ================================ */
 
@@ -152,11 +153,12 @@ data_error_t data_database_writer_update_diagram_parent_id ( data_database_write
  *  \brief creates a new classifier and returns its id
  *
  *  \param this_ pointer to own object attributes
- *  \param classifier data of the new classifier record to be created. The id should be DATA_ROW_ID_VOID unless a classifier with known, unique id shall be created.
+ *  \param classifier data of the new classifier record to be created.
+ *                    The id should be DATA_ROW_ID_VOID unless a classifier with known, unique id shall be created.
  *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_create_classifier( data_database_writer_t *this_, const data_classifier_t *classifier, data_row_id_t* out_new_id );
+u8_error_t data_database_writer_create_classifier( data_database_writer_t *this_, const data_classifier_t *classifier, data_row_id_t* out_new_id );
 
 /*!
  *  \brief deletes a classifier record and returns its old data
@@ -165,10 +167,11 @@ data_error_t data_database_writer_create_classifier( data_database_writer_t *thi
  *
  *  \param this_ pointer to own object attributes
  *  \param obj_id id of the classifier record to be deleted.
- *  \param[out] out_old_classifier storage, where the contents of the deleted, old record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \param[out] out_old_classifier storage, where the contents of the deleted, old record is stored.
+ *                                 NULL if old data shall not be returned.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_delete_classifier( data_database_writer_t *this_, data_row_id_t obj_id, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_delete_classifier( data_database_writer_t *this_, data_row_id_t obj_id, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: stereotype
@@ -176,10 +179,11 @@ data_error_t data_database_writer_delete_classifier( data_database_writer_t *thi
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_stereotype new stereotype text of the classifier
- *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored.
+ *                                 NULL if old data shall not be returned.
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_stereotype ( data_database_writer_t *this_, data_row_id_t classifier_id, const char* new_classifier_stereotype, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_stereotype ( data_database_writer_t *this_, data_row_id_t classifier_id, const char* new_classifier_stereotype, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: description
@@ -188,9 +192,9 @@ data_error_t data_database_writer_update_classifier_stereotype ( data_database_w
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_description new description text of the classifier
  *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_description ( data_database_writer_t *this_, data_row_id_t classifier_id, const char* new_classifier_description, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_description ( data_database_writer_t *this_, data_row_id_t classifier_id, const char* new_classifier_description, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: name
@@ -199,9 +203,9 @@ data_error_t data_database_writer_update_classifier_description ( data_database_
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_name new name of the classifier
  *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_name ( data_database_writer_t *this_, data_row_id_t classifier_id, const char* new_classifier_name, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_name ( data_database_writer_t *this_, data_row_id_t classifier_id, const char* new_classifier_name, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: main_type
@@ -210,9 +214,9 @@ data_error_t data_database_writer_update_classifier_name ( data_database_writer_
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_main_type new main_type of the classifier
  *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_main_type ( data_database_writer_t *this_, data_row_id_t classifier_id, data_classifier_type_t new_classifier_main_type, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_main_type ( data_database_writer_t *this_, data_row_id_t classifier_id, data_classifier_type_t new_classifier_main_type, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: x_order
@@ -221,9 +225,9 @@ data_error_t data_database_writer_update_classifier_main_type ( data_database_wr
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_x_order new x_order of the classifier
  *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_x_order ( data_database_writer_t *this_, data_row_id_t classifier_id, int32_t new_classifier_x_order, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_x_order ( data_database_writer_t *this_, data_row_id_t classifier_id, int32_t new_classifier_x_order, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: y_order
@@ -232,9 +236,9 @@ data_error_t data_database_writer_update_classifier_x_order ( data_database_writ
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_y_order new y_order of the classifier
  *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_y_order ( data_database_writer_t *this_, data_row_id_t classifier_id, int32_t new_classifier_y_order, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_y_order ( data_database_writer_t *this_, data_row_id_t classifier_id, int32_t new_classifier_y_order, data_classifier_t *out_old_classifier );
 
 /*!
  *  \brief updates the classifier attribute: list_order
@@ -243,9 +247,9 @@ data_error_t data_database_writer_update_classifier_y_order ( data_database_writ
  *  \param classifier_id id of the classifier to be updated
  *  \param new_classifier_list_order new list_order of the classifier
  *  \param[out] out_old_classifier storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_classifier_list_order ( data_database_writer_t *this_, data_row_id_t classifier_id, int32_t new_classifier_list_order, data_classifier_t *out_old_classifier );
+u8_error_t data_database_writer_update_classifier_list_order ( data_database_writer_t *this_, data_row_id_t classifier_id, int32_t new_classifier_list_order, data_classifier_t *out_old_classifier );
 
 /* ================================ DIAGRAMELEMENT ================================ */
 
@@ -255,9 +259,9 @@ data_error_t data_database_writer_update_classifier_list_order ( data_database_w
  *  \param this_ pointer to own object attributes
  *  \param diagramelement data of the new diagramelement record to be created. The id should be DATA_ROW_ID_VOID unless a diagramelement with known, unique id shall be created.
  *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_create_diagramelement( data_database_writer_t *this_, const data_diagramelement_t *diagramelement, data_row_id_t* out_new_id );
+u8_error_t data_database_writer_create_diagramelement( data_database_writer_t *this_, const data_diagramelement_t *diagramelement, data_row_id_t* out_new_id );
 
 /*!
  *  \brief deletes a diagramelement record and returns its old data
@@ -265,9 +269,9 @@ data_error_t data_database_writer_create_diagramelement( data_database_writer_t
  *  \param this_ pointer to own object attributes
  *  \param obj_id id of the diagramelement record to be deleted.
  *  \param[out] out_old_diagramelement storage, where the contents of the deleted, old record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_delete_diagramelement( data_database_writer_t *this_, data_row_id_t obj_id, data_diagramelement_t *out_old_diagramelement );
+u8_error_t data_database_writer_delete_diagramelement( data_database_writer_t *this_, data_row_id_t obj_id, data_diagramelement_t *out_old_diagramelement );
 
 /*!
  *  \brief updates the diagramelement attribute: display_flags
@@ -276,9 +280,9 @@ data_error_t data_database_writer_delete_diagramelement( data_database_writer_t
  *  \param diagramelement_id id of the diagramelement to be updated
  *  \param new_display_flags new display flags of the diagramelement
  *  \param[out] out_old_diagramelement storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagramelement_display_flags ( data_database_writer_t *this_, data_row_id_t diagramelement_id, data_diagramelement_flag_t new_display_flags, data_diagramelement_t *out_old_diagramelement );
+u8_error_t data_database_writer_update_diagramelement_display_flags ( data_database_writer_t *this_, data_row_id_t diagramelement_id, data_diagramelement_flag_t new_display_flags, data_diagramelement_t *out_old_diagramelement );
 
 /*!
  *  \brief updates the diagramelement attribute: focused_feature_id
@@ -287,9 +291,9 @@ data_error_t data_database_writer_update_diagramelement_display_flags ( data_dat
  *  \param diagramelement_id id of the diagramelement to be updated
  *  \param new_focused_feature_id new focused_feature_id of the diagramelement
  *  \param[out] out_old_diagramelement storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_diagramelement_focused_feature_id ( data_database_writer_t *this_, data_row_id_t diagramelement_id, data_row_id_t new_focused_feature_id, data_diagramelement_t *out_old_diagramelement );
+u8_error_t data_database_writer_update_diagramelement_focused_feature_id ( data_database_writer_t *this_, data_row_id_t diagramelement_id, data_row_id_t new_focused_feature_id, data_diagramelement_t *out_old_diagramelement );
 
 /* ================================ FEATURE ================================ */
 
@@ -299,9 +303,9 @@ data_error_t data_database_writer_update_diagramelement_focused_feature_id ( dat
  *  \param this_ pointer to own object attributes
  *  \param feature data of the new feature record to be created. The id should be DATA_ROW_ID_VOID unless a feature with known, unique id shall be created.
  *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_create_feature ( data_database_writer_t *this_, const data_feature_t *feature, data_row_id_t* out_new_id );
+u8_error_t data_database_writer_create_feature ( data_database_writer_t *this_, const data_feature_t *feature, data_row_id_t* out_new_id );
 
 /*!
  *  \brief deletes a feature record and returns its old data
@@ -309,9 +313,9 @@ data_error_t data_database_writer_create_feature ( data_database_writer_t *this_
  *  \param this_ pointer to own object attributes
  *  \param obj_id id of the feature record to be deleted.
  *  \param[out] out_old_feature storage, where the contents of the deleted, old record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_delete_feature ( data_database_writer_t *this_, data_row_id_t obj_id, data_feature_t *out_old_feature );
+u8_error_t data_database_writer_delete_feature ( data_database_writer_t *this_, data_row_id_t obj_id, data_feature_t *out_old_feature );
 
 /*!
  *  \brief updates the feature attribute: main_type
@@ -320,9 +324,9 @@ data_error_t data_database_writer_delete_feature ( data_database_writer_t *this_
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_type new feature_type of the feature
  *  \param[out] out_old_feature storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_feature_main_type ( data_database_writer_t *this_, data_row_id_t feature_id, data_feature_type_t new_feature_type, data_feature_t *out_old_feature );
+u8_error_t data_database_writer_update_feature_main_type ( data_database_writer_t *this_, data_row_id_t feature_id, data_feature_type_t new_feature_type, data_feature_t *out_old_feature );
 
 /*!
  *  \brief updates the feature attribute: key
@@ -331,9 +335,9 @@ data_error_t data_database_writer_update_feature_main_type ( data_database_write
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_key new key/name of the feature
  *  \param[out] out_old_feature storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_feature_key ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_key, data_feature_t *out_old_feature );
+u8_error_t data_database_writer_update_feature_key ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_key, data_feature_t *out_old_feature );
 
 /*!
  *  \brief updates the feature attribute: value
@@ -342,9 +346,9 @@ data_error_t data_database_writer_update_feature_key ( data_database_writer_t *t
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_value new value/type of the feature
  *  \param[out] out_old_feature storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_feature_value ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_value, data_feature_t *out_old_feature );
+u8_error_t data_database_writer_update_feature_value ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_value, data_feature_t *out_old_feature );
 
 /*!
  *  \brief updates the feature attribute: description
@@ -353,9 +357,9 @@ data_error_t data_database_writer_update_feature_value ( data_database_writer_t
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_description new description text of the feature
  *  \param[out] out_old_feature storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_feature_description ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_description, data_feature_t *out_old_feature );
+u8_error_t data_database_writer_update_feature_description ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_description, data_feature_t *out_old_feature );
 
 /*!
  *  \brief updates the feature attribute: list_order
@@ -364,9 +368,9 @@ data_error_t data_database_writer_update_feature_description ( data_database_wri
  *  \param feature_id id of the feature to be updated
  *  \param new_feature_list_order new list_order of the feature
  *  \param[out] out_old_feature storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_feature_list_order ( data_database_writer_t *this_, data_row_id_t feature_id, int32_t new_feature_list_order, data_feature_t *out_old_feature );
+u8_error_t data_database_writer_update_feature_list_order ( data_database_writer_t *this_, data_row_id_t feature_id, int32_t new_feature_list_order, data_feature_t *out_old_feature );
 
 /* ================================ RELATIONSHIP ================================ */
 
@@ -376,9 +380,9 @@ data_error_t data_database_writer_update_feature_list_order ( data_database_writ
  *  \param this_ pointer to own object attributes
  *  \param relationship data of the new relationship record to be created. The id should be DATA_ROW_ID_VOID unless a relationship with known, unique id shall be created.
  *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_create_relationship ( data_database_writer_t *this_, const data_relationship_t *relationship, data_row_id_t* out_new_id );
+u8_error_t data_database_writer_create_relationship ( data_database_writer_t *this_, const data_relationship_t *relationship, data_row_id_t* out_new_id );
 
 /*!
  *  \brief deletes a relationship record and returns its old data
@@ -386,9 +390,9 @@ data_error_t data_database_writer_create_relationship ( data_database_writer_t *
  *  \param this_ pointer to own object attributes
  *  \param obj_id id of the relationship record to be deleted.
  *  \param[out] out_old_relationship storage, where the contents of the deleted, old record is stored. NULL if old data shall not be returned.
- *  \return DATA_ERROR_NONE in case of success, an error code in case of error.
+ *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
-data_error_t data_database_writer_delete_relationship ( data_database_writer_t *this_, data_row_id_t obj_id, data_relationship_t *out_old_relationship );
+u8_error_t data_database_writer_delete_relationship ( data_database_writer_t *this_, data_row_id_t obj_id, data_relationship_t *out_old_relationship );
 
 /*!
  *  \brief updates the relationship attribute: main_type
@@ -397,9 +401,9 @@ data_error_t data_database_writer_delete_relationship ( data_database_writer_t *
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_type new relationship_type of the relationship
  *  \param[out] out_old_relationship storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_relationship_main_type ( data_database_writer_t *this_, data_row_id_t relationship_id, data_relationship_type_t new_relationship_type, data_relationship_t *out_old_relationship );
+u8_error_t data_database_writer_update_relationship_main_type ( data_database_writer_t *this_, data_row_id_t relationship_id, data_relationship_type_t new_relationship_type, data_relationship_t *out_old_relationship );
 
 /*!
  *  \brief updates the relationship attribute: name
@@ -408,9 +412,9 @@ data_error_t data_database_writer_update_relationship_main_type ( data_database_
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_name new name of the relationship
  *  \param[out] out_old_relationship storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_relationship_name ( data_database_writer_t *this_, data_row_id_t relationship_id, const char* new_relationship_name, data_relationship_t *out_old_relationship );
+u8_error_t data_database_writer_update_relationship_name ( data_database_writer_t *this_, data_row_id_t relationship_id, const char* new_relationship_name, data_relationship_t *out_old_relationship );
 
 /*!
  *  \brief updates the relationship attribute: description
@@ -419,9 +423,9 @@ data_error_t data_database_writer_update_relationship_name ( data_database_write
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_description new description text of the relationship
  *  \param[out] out_old_relationship storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_relationship_description ( data_database_writer_t *this_, data_row_id_t relationship_id, const char* new_relationship_description, data_relationship_t *out_old_relationship );
+u8_error_t data_database_writer_update_relationship_description ( data_database_writer_t *this_, data_row_id_t relationship_id, const char* new_relationship_description, data_relationship_t *out_old_relationship );
 
 /*!
  *  \brief updates the relationship attribute: list_order
@@ -430,9 +434,9 @@ data_error_t data_database_writer_update_relationship_description ( data_databas
  *  \param relationship_id id of the relationship to be updated
  *  \param new_relationship_list_order new list_order of the relationship
  *  \param[out] out_old_relationship storage, where the contents of the old, unmodified record is stored. NULL if old data shall not be returned.
- *  \return error id in case of an error, DATA_ERROR_NONE otherwise
+ *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
-data_error_t data_database_writer_update_relationship_list_order ( data_database_writer_t *this_, data_row_id_t relationship_id, int32_t new_relationship_list_order, data_relationship_t *out_old_relationship );
+u8_error_t data_database_writer_update_relationship_list_order ( data_database_writer_t *this_, data_row_id_t relationship_id, int32_t new_relationship_list_order, data_relationship_t *out_old_relationship );
 
 /* ================================ private ================================ */
 
@@ -444,9 +448,9 @@ data_error_t data_database_writer_update_relationship_list_order ( data_database
  *  \param this_ pointer to own object attributes
  *  \param sql_statement statement to be executed.
  *  \param[out] out_new_id if fetch_new_id, the id of the newly created row is returned
- *  \return DATA_ERROR_NONE in case of success, an error id otherwise; DATA_ERROR_READ_ONLY_DB if read only
+ *  \return U8_ERROR_NONE in case of success, U8_ERROR_DUPLICATE if a key is not unique; U8_ERROR_READ_ONLY_DB if read only
  */
-data_error_t data_database_writer_private_execute_create_command ( data_database_writer_t *this_, const char* sql_statement, data_row_id_t* out_new_id );
+u8_error_t data_database_writer_private_execute_create_command ( data_database_writer_t *this_, const char* sql_statement, data_row_id_t* out_new_id );
 
 /*!
  *  \brief executes a "BEGIN TRANSACTION" command
@@ -454,9 +458,9 @@ data_error_t data_database_writer_private_execute_create_command ( data_database
  *  This function does not care about locks. It does not sent notifications.
  *
  *  \param this_ pointer to own object attributes
- *  \return DATA_ERROR_NONE in case of success, an error id otherwise, e.g. DATA_ERROR_NO_DB in case the database is not open
+ *  \return U8_ERROR_NONE in case of success, an error id otherwise, e.g. U8_ERROR_NO_DB in case the database is not open
  */
-data_error_t data_database_writer_private_transaction_begin ( data_database_writer_t *this_ );
+u8_error_t data_database_writer_private_transaction_begin ( data_database_writer_t *this_ );
 
 /*!
  *  \brief executes a "COMMIT TRANSACTION" command
@@ -464,9 +468,9 @@ data_error_t data_database_writer_private_transaction_begin ( data_database_writ
  *  This function does not care about locks. It does not sent notifications.
  *
  *  \param this_ pointer to own object attributes
- *  \return DATA_ERROR_NONE in case of success, an error id otherwise
+ *  \return U8_ERROR_NONE in case of success, an error id otherwise
  */
-data_error_t data_database_writer_private_transaction_commit ( data_database_writer_t *this_ );
+u8_error_t data_database_writer_private_transaction_commit ( data_database_writer_t *this_ );
 
 /*!
  *  \brief sends one SQL command to the database within a transaction
@@ -475,11 +479,9 @@ data_error_t data_database_writer_private_transaction_commit ( data_database_wri
  *
  *  \param this_ pointer to own object attributes
  *  \param sql_statement statement to be executed.
- *  \return DATA_ERROR_NONE in case of success, an error id otherwise; DATA_ERROR_READ_ONLY_DB if read only
+ *  \return U8_ERROR_NONE in case of success, an error id otherwise; U8_ERROR_READ_ONLY_DB if read only
  */
-data_error_t data_database_writer_private_transaction_issue_command ( data_database_writer_t *this_, const char* sql_statement );
-
-#include "storage/data_database_writer.inl"
+u8_error_t data_database_writer_private_transaction_issue_command ( data_database_writer_t *this_, const char* sql_statement );
 
 #endif  /* DATA_DATABASE_WRITER_H */
 
