@@ -7,11 +7,11 @@
 #include <sqlite3.h>
 #include <assert.h>
 
-data_error_t data_database_classifier_reader_init ( data_database_classifier_reader_t *this_, data_database_t *database )
+u8_error_t data_database_classifier_reader_init ( data_database_classifier_reader_t *this_, data_database_t *database )
 {
     TRACE_BEGIN();
     assert( NULL != database );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
 
     (*this_).database = database;
 
@@ -35,10 +35,10 @@ data_error_t data_database_classifier_reader_init ( data_database_classifier_rea
     return result;
 }
 
-data_error_t data_database_classifier_reader_destroy ( data_database_classifier_reader_t *this_ )
+u8_error_t data_database_classifier_reader_destroy ( data_database_classifier_reader_t *this_ )
 {
     TRACE_BEGIN();
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
 
     result |= data_database_classifier_reader_private_close( this_ );
 
@@ -82,10 +82,17 @@ static const char DATA_DATABASE_READER_SELECT_CLASSIFIERS_BY_DIAGRAM_ID[] =
     "FROM classifiers "
     "INNER JOIN diagramelements ON diagramelements.classifier_id=classifiers.id "
     "WHERE diagramelements.diagram_id=? "
-    "ORDER BY classifiers.list_order ASC;";
+    "ORDER BY diagramelements.id ASC;";
+    /* To ensure reporducible results of json esports, ordering by a unique key is required here. */
+    /* Ordering by 2 keys did not produce the expected results with sqlite3 3.34.1 */
+    /* "ORDER BY classifiers.list_order ASC,diagramelements.id ASC;"; */
+    /* see also https://sqlite.org/forum/forumpost/e1033dab18c262ac4b36cdf7c65bf87a5aaaecab3b3ba100e4588fc30e50f9fb */
 
 /*!
  *  \brief search statement to iterate over all classifiers sorted by number of parent-containers
+ *
+ *  The "order by cnt" is important to ensure parent objects are iterated first, e.g. for xmi export
+ *  The "order by id" is important to get reproducable results, e.g. for json export
  */
 static const char DATA_DATABASE_READER_SELECT_ALL_CLASSIFIERS[] =
     "SELECT id,main_type,stereotype,name,description,x_order,y_order,list_order,uuid,"
@@ -93,7 +100,7 @@ static const char DATA_DATABASE_READER_SELECT_ALL_CLASSIFIERS[] =
         "WHERE (relationships.to_classifier_id=classifiers.id) AND (relationships.to_feature_id IS NULL) "
         "AND (relationships.main_type=300)) AS cnt "
     "FROM classifiers "
-    "ORDER BY cnt ASC;";
+    "ORDER BY cnt ASC,id ASC;";
 
 /*!
  *  \brief the column id of the result where this parameter is stored: id
@@ -160,13 +167,13 @@ static const int RESULT_CLASSIFIER_FOCUSED_FEATURE_ID_COLUMN = 11;
  */
 static const int RESULT_CLASSIFIER_DIAGELE_UUID_COLUMN = 12;
 
-data_error_t data_database_classifier_reader_get_classifier_by_id( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_classifier_by_id( data_database_classifier_reader_t *this_,
                                                                    data_row_id_t id,
                                                                    data_classifier_t *out_classifier )
 {
     TRACE_BEGIN();
     assert( NULL != out_classifier );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -180,7 +187,7 @@ data_error_t data_database_classifier_reader_get_classifier_by_id( data_database
         if ( SQLITE_ROW != sqlite_err )
         {
             TSLOG_ANOMALY( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -204,7 +211,7 @@ data_error_t data_database_classifier_reader_get_classifier_by_id( data_database
         if ( SQLITE_DONE != sqlite_err )
         {
             TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -212,14 +219,14 @@ data_error_t data_database_classifier_reader_get_classifier_by_id( data_database
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_classifier_by_name( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_classifier_by_name( data_database_classifier_reader_t *this_,
                                                                      const char *name,
                                                                      data_classifier_t *out_classifier )
 {
     TRACE_BEGIN();
     assert( NULL != out_classifier );
     assert( NULL != name );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -232,8 +239,8 @@ data_error_t data_database_classifier_reader_get_classifier_by_name( data_databa
         sqlite_err = sqlite3_step( prepared_statement );
         if ( SQLITE_ROW != sqlite_err )
         {
-            TSLOG_EVENT( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            TSLOG_ANOMALY( "sqlite3_step did not find a row." );
+            result |= U8_ERROR_NOT_FOUND;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -256,8 +263,8 @@ data_error_t data_database_classifier_reader_get_classifier_by_name( data_databa
         sqlite_err = sqlite3_step( prepared_statement );
         if ( SQLITE_DONE != sqlite_err )
         {
-            TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            TSLOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -265,14 +272,14 @@ data_error_t data_database_classifier_reader_get_classifier_by_name( data_databa
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_database_classifier_reader_t *this_,
                                                                       const char *uuid,
                                                                       data_classifier_t *out_classifier )
 {
     TRACE_BEGIN();
     assert( NULL != out_classifier );
     assert( NULL != uuid );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -285,8 +292,8 @@ data_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_datab
         sqlite_err = sqlite3_step( prepared_statement );
         if ( SQLITE_ROW != sqlite_err )
         {
-            TSLOG_EVENT( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            TSLOG_ANOMALY( "sqlite3_step did not find a row." );
+            result |= U8_ERROR_NOT_FOUND;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -309,8 +316,8 @@ data_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_datab
         sqlite_err = sqlite3_step( prepared_statement );
         if ( SQLITE_DONE != sqlite_err )
         {
-            TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            TSLOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -318,7 +325,7 @@ data_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_datab
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_classifiers_by_diagram_id( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_classifiers_by_diagram_id( data_database_classifier_reader_t *this_,
                                                                             data_row_id_t diagram_id,
                                                                             uint32_t max_out_array_size,
                                                                             data_visible_classifier_t (*out_visible_classifier)[],
@@ -327,7 +334,7 @@ data_error_t data_database_classifier_reader_get_classifiers_by_diagram_id( data
     TRACE_BEGIN();
     assert( NULL != out_visible_classifier_count );
     assert( NULL != out_visible_classifier );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -345,7 +352,7 @@ data_error_t data_database_classifier_reader_get_classifiers_by_diagram_id( data
             if (( SQLITE_ROW != sqlite_err )&&( SQLITE_DONE != sqlite_err ))
             {
                 TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-                result |= DATA_ERROR_AT_DB;
+                result |= U8_ERROR_AT_DB;
             }
             if (( SQLITE_ROW == sqlite_err )&&(row_index < max_out_array_size))
             {
@@ -390,7 +397,7 @@ data_error_t data_database_classifier_reader_get_classifiers_by_diagram_id( data
             if (( SQLITE_ROW == sqlite_err )&&(row_index >= max_out_array_size))
             {
                 TSLOG_ANOMALY_INT( "out_visible_classifier[] full:", (row_index+1) );
-                result |= DATA_ERROR_ARRAY_BUFFER_EXCEEDED;
+                result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
             }
             if ( SQLITE_DONE == sqlite_err )
             {
@@ -403,13 +410,13 @@ data_error_t data_database_classifier_reader_get_classifiers_by_diagram_id( data
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_all_classifiers_iterator( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_all_classifiers_iterator( data_database_classifier_reader_t *this_,
                                                                            data_database_iterator_classifiers_t *io_classifier_iterator
                                                                          )
 {
     TRACE_BEGIN();
     assert( NULL != io_classifier_iterator );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
 
     {
         sqlite3_stmt *prepared_statement;
@@ -419,7 +426,7 @@ data_error_t data_database_classifier_reader_get_all_classifiers_iterator( data_
                                                                    sizeof( DATA_DATABASE_READER_SELECT_ALL_CLASSIFIERS ),
                                                                    &prepared_statement
                                                                  );
-        if ( result == DATA_ERROR_NONE )
+        if ( result == U8_ERROR_NONE )
         {
             result |= data_database_iterator_classifiers_reinit ( io_classifier_iterator, (*this_).database, prepared_statement );
         }
@@ -508,13 +515,13 @@ static const int RESULT_FEATURE_LIST_UUID_COLUMN = 7;
  */
 static const int RESULT_FEATURE_DIAGRAMELEMENTS_ID_COLUMN = 8;
 
-data_error_t data_database_classifier_reader_get_feature_by_id ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_feature_by_id ( data_database_classifier_reader_t *this_,
                                                                  data_row_id_t id,
                                                                  data_feature_t *out_feature )
 {
     TRACE_BEGIN();
     assert( NULL != out_feature );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -528,7 +535,7 @@ data_error_t data_database_classifier_reader_get_feature_by_id ( data_database_c
         if ( SQLITE_ROW != sqlite_err )
         {
             TSLOG_ANOMALY( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -551,7 +558,7 @@ data_error_t data_database_classifier_reader_get_feature_by_id ( data_database_c
         if ( SQLITE_DONE != sqlite_err )
         {
             TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -559,13 +566,13 @@ data_error_t data_database_classifier_reader_get_feature_by_id ( data_database_c
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database_classifier_reader_t *this_,
                                                                    const char *uuid,
                                                                    data_feature_t *out_feature )
 {
     TRACE_BEGIN();
     assert( NULL != out_feature );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -579,7 +586,7 @@ data_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database
         if ( SQLITE_ROW != sqlite_err )
         {
             TSLOG_ANOMALY( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_NOT_FOUND;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -601,8 +608,8 @@ data_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database
         sqlite_err = sqlite3_step( prepared_statement );
         if ( SQLITE_DONE != sqlite_err )
         {
-            TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            TSLOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -610,7 +617,7 @@ data_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_features_by_classifier_id ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_features_by_classifier_id ( data_database_classifier_reader_t *this_,
                                                                              data_row_id_t classifier_id,
                                                                              uint32_t max_out_array_size,
                                                                              data_feature_t (*out_feature)[],
@@ -619,7 +626,7 @@ data_error_t data_database_classifier_reader_get_features_by_classifier_id ( dat
     TRACE_BEGIN();
     assert( NULL != out_feature_count );
     assert( NULL != out_feature );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -637,7 +644,7 @@ data_error_t data_database_classifier_reader_get_features_by_classifier_id ( dat
             if (( SQLITE_ROW != sqlite_err )&&( SQLITE_DONE != sqlite_err ))
             {
                 TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-                result |= DATA_ERROR_AT_DB;
+                result |= U8_ERROR_AT_DB;
             }
             if (( SQLITE_ROW == sqlite_err )&&(row_index < max_out_array_size))
             {
@@ -661,7 +668,7 @@ data_error_t data_database_classifier_reader_get_features_by_classifier_id ( dat
             if (( SQLITE_ROW == sqlite_err )&&(row_index >= max_out_array_size))
             {
                 TSLOG_ANOMALY_INT( "out_feature[] full:", (row_index+1) );
-                result |= DATA_ERROR_ARRAY_BUFFER_EXCEEDED;
+                result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
             }
             if ( SQLITE_DONE == sqlite_err )
             {
@@ -674,7 +681,7 @@ data_error_t data_database_classifier_reader_get_features_by_classifier_id ( dat
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_database_classifier_reader_t *this_,
                                                                           data_row_id_t diagram_id,
                                                                           uint32_t max_out_array_size,
                                                                           data_feature_t (*out_feature)[],
@@ -683,7 +690,7 @@ data_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_d
     TRACE_BEGIN();
     assert( NULL != out_feature_count );
     assert( NULL != out_feature );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -701,7 +708,7 @@ data_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_d
             if (( SQLITE_ROW != sqlite_err )&&( SQLITE_DONE != sqlite_err ))
             {
                 TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-                result |= DATA_ERROR_AT_DB;
+                result |= U8_ERROR_AT_DB;
             }
             if (( SQLITE_ROW == sqlite_err )&&(row_index < max_out_array_size))
             {
@@ -726,7 +733,7 @@ data_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_d
             if (( SQLITE_ROW == sqlite_err )&&(row_index >= max_out_array_size))
             {
                 TSLOG_ANOMALY_INT( "out_feature[] full:", (row_index+1) );
-                result |= DATA_ERROR_ARRAY_BUFFER_EXCEEDED;
+                result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
             }
             if ( SQLITE_DONE == sqlite_err )
             {
@@ -852,11 +859,11 @@ static const int RESULT_RELATIONSHIP_SOURCE_DIAGRAMELEMENTS_ID_COLUMN = 10;
  */
 static const int RESULT_RELATIONSHIP_DEST_DIAGRAMELEMENTS_ID_COLUMN = 11;
 
-data_error_t data_database_classifier_reader_get_relationship_by_id ( data_database_classifier_reader_t *this_, data_row_id_t id, data_relationship_t *out_relationship )
+u8_error_t data_database_classifier_reader_get_relationship_by_id ( data_database_classifier_reader_t *this_, data_row_id_t id, data_relationship_t *out_relationship )
 {
     TRACE_BEGIN();
     assert( NULL != out_relationship );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -870,7 +877,7 @@ data_error_t data_database_classifier_reader_get_relationship_by_id ( data_datab
         if ( SQLITE_ROW != sqlite_err )
         {
             TSLOG_ANOMALY( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -903,7 +910,7 @@ data_error_t data_database_classifier_reader_get_relationship_by_id ( data_datab
         if ( SQLITE_DONE != sqlite_err )
         {
             TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -911,13 +918,13 @@ data_error_t data_database_classifier_reader_get_relationship_by_id ( data_datab
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_database_classifier_reader_t *this_,
                                                                         const char *uuid,
                                                                         data_relationship_t *out_relationship )
 {
     TRACE_BEGIN();
     assert( NULL != out_relationship );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -931,7 +938,7 @@ data_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_dat
         if ( SQLITE_ROW != sqlite_err )
         {
             TSLOG_ANOMALY( "sqlite3_step did not find a row." );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            result |= U8_ERROR_NOT_FOUND;
         }
 
         if ( SQLITE_ROW == sqlite_err )
@@ -963,8 +970,8 @@ data_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_dat
         sqlite_err = sqlite3_step( prepared_statement );
         if ( SQLITE_DONE != sqlite_err )
         {
-            TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-            result |= DATA_ERROR_DB_STRUCTURE;
+            TSLOG_ERROR_INT( "sqlite3_step not done yet:", sqlite_err );
+            result |= U8_ERROR_DB_STRUCTURE;
         }
     }
 
@@ -972,7 +979,7 @@ data_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_dat
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_relationships_by_classifier_id ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_relationships_by_classifier_id ( data_database_classifier_reader_t *this_,
                                                                                   data_row_id_t classifier_id,
                                                                                   uint32_t max_out_array_size,
                                                                                   data_relationship_t (*out_relationship)[],
@@ -981,7 +988,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_classifier_id
     TRACE_BEGIN();
     assert( NULL != out_relationship_count );
     assert( NULL != out_relationship );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -999,7 +1006,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_classifier_id
             if (( SQLITE_ROW != sqlite_err )&&( SQLITE_DONE != sqlite_err ))
             {
                 TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-                result |= DATA_ERROR_AT_DB;
+                result |= U8_ERROR_AT_DB;
             }
             if (( SQLITE_ROW == sqlite_err )&&(row_index < max_out_array_size))
             {
@@ -1033,7 +1040,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_classifier_id
             if (( SQLITE_ROW == sqlite_err )&&(row_index >= max_out_array_size))
             {
                 TSLOG_ANOMALY_INT( "out_relationship[] full:", (row_index+1) );
-                result |= DATA_ERROR_ARRAY_BUFFER_EXCEEDED;
+                result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
             }
             if ( SQLITE_DONE == sqlite_err )
             {
@@ -1046,7 +1053,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_classifier_id
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_relationships_by_feature_id ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_relationships_by_feature_id ( data_database_classifier_reader_t *this_,
                                                                                data_row_id_t feature_id,
                                                                                uint32_t max_out_array_size,
                                                                                data_relationship_t (*out_relationship)[],
@@ -1055,7 +1062,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_feature_id ( d
     TRACE_BEGIN();
     assert( NULL != out_relationship_count );
     assert( NULL != out_relationship );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -1073,7 +1080,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_feature_id ( d
             if (( SQLITE_ROW != sqlite_err )&&( SQLITE_DONE != sqlite_err ))
             {
                 TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-                result |= DATA_ERROR_AT_DB;
+                result |= U8_ERROR_AT_DB;
             }
             if (( SQLITE_ROW == sqlite_err )&&(row_index < max_out_array_size))
             {
@@ -1107,7 +1114,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_feature_id ( d
             if (( SQLITE_ROW == sqlite_err )&&(row_index >= max_out_array_size))
             {
                 TSLOG_ANOMALY_INT( "out_relationship[] full:", (row_index+1) );
-                result |= DATA_ERROR_ARRAY_BUFFER_EXCEEDED;
+                result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
             }
             if ( SQLITE_DONE == sqlite_err )
             {
@@ -1120,7 +1127,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_feature_id ( d
     return result;
 }
 
-data_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( data_database_classifier_reader_t *this_,
+u8_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( data_database_classifier_reader_t *this_,
                                                                                data_row_id_t diagram_id,
                                                                                uint32_t max_out_array_size,
                                                                                data_relationship_t (*out_relationship)[],
@@ -1129,7 +1136,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( d
     TRACE_BEGIN();
     assert( NULL != out_relationship_count );
     assert( NULL != out_relationship );
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
     int sqlite_err;
     sqlite3_stmt *prepared_statement;
 
@@ -1147,7 +1154,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( d
             if (( SQLITE_ROW != sqlite_err )&&( SQLITE_DONE != sqlite_err ))
             {
                 TSLOG_ERROR_INT( "sqlite3_step failed:", sqlite_err );
-                result |= DATA_ERROR_AT_DB;
+                result |= U8_ERROR_AT_DB;
             }
             if (( SQLITE_ROW == sqlite_err )&&(row_index < max_out_array_size))
             {
@@ -1183,7 +1190,7 @@ data_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( d
             if (( SQLITE_ROW == sqlite_err )&&(row_index >= max_out_array_size))
             {
                 TSLOG_ANOMALY_INT( "out_relationship[] full:", (row_index+1) );
-                result |= DATA_ERROR_ARRAY_BUFFER_EXCEEDED;
+                result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
             }
             if ( SQLITE_DONE == sqlite_err )
             {
@@ -1198,10 +1205,10 @@ data_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( d
 
 /* ================================ private ================================ */
 
-data_error_t data_database_classifier_reader_private_open ( data_database_classifier_reader_t *this_ )
+u8_error_t data_database_classifier_reader_private_open ( data_database_classifier_reader_t *this_ )
 {
     TRACE_BEGIN();
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
 
     {
         result |= data_database_classifier_reader_private_prepare_statement ( this_,
@@ -1282,7 +1289,7 @@ data_error_t data_database_classifier_reader_private_open ( data_database_classi
                                                                               &((*this_).private_prepared_query_relationships_by_diagram_id)
                                                                             );
 
-        if ( result != DATA_ERROR_NONE )
+        if ( result != U8_ERROR_NONE )
         {
             TSLOG_ERROR( "A prepared statement could not be prepared." );
         }
@@ -1292,10 +1299,10 @@ data_error_t data_database_classifier_reader_private_open ( data_database_classi
     return result;
 }
 
-data_error_t data_database_classifier_reader_private_close ( data_database_classifier_reader_t *this_ )
+u8_error_t data_database_classifier_reader_private_close ( data_database_classifier_reader_t *this_ )
 {
     TRACE_BEGIN();
-    data_error_t result = DATA_ERROR_NONE;
+    u8_error_t result = U8_ERROR_NONE;
 
     {
         result |= data_database_classifier_reader_private_finalize_statement( this_, (*this_).private_prepared_query_classifier_by_id );
