@@ -2,8 +2,7 @@
 
 #include "gui_clipboard.h"
 #include "trace.h"
-#include "json/json_deserializer.h"
-#include "ctrl_error.h"
+#include "u8/u8_error.h"
 #include "set/data_stat.h"
 #include "util/string/utf8string.h"
 #include <assert.h>
@@ -30,7 +29,7 @@ void gui_clipboard_init ( gui_clipboard_t *this_,
                                                      );
 
     io_exporter_light_init ( &((*this_).exporter), db_reader );
-    json_import_to_database_init ( &((*this_).importer), db_reader, controller );
+    io_importer_init ( &((*this_).importer), db_reader, controller );
 
     TRACE_END();
 }
@@ -40,7 +39,7 @@ void gui_clipboard_destroy ( gui_clipboard_t *this_ )
     TRACE_BEGIN();
 
     io_exporter_light_destroy ( &((*this_).exporter) );
-    json_import_to_database_destroy ( &((*this_).importer) );
+    io_importer_destroy ( &((*this_).importer) );
 
     (*this_).the_clipboard = NULL;
     (*this_).message_to_user = NULL;
@@ -118,18 +117,18 @@ void gui_clipboard_private_copy_clipboard_to_db( gui_clipboard_t *this_, const c
     assert( NULL != json_text );
     TRACE_INFO_INT ( "(*this_).destination_diagram_id:", (*this_).destination_diagram_id );
 
-    data_error_t parse_error;
+    u8_error_t parse_error;
     data_stat_t stat;
     data_stat_init(&stat);
     uint32_t read_err_pos;
-    parse_error = json_import_to_database_import_buf_to_db( &((*this_).importer),
-                                                            json_text,
-                                                            (*this_).destination_diagram_id,
-                                                            &stat,
-                                                            &read_err_pos
-                                                          );
+    parse_error = io_importer_import_clipboard( &((*this_).importer),
+                                                json_text,
+                                                (*this_).destination_diagram_id,
+                                                &stat,
+                                                &read_err_pos
+                                              );
 
-    if ( DATA_ERROR_NONE != parse_error )
+    if ( U8_ERROR_NONE != parse_error )
     {
         gui_simple_message_to_user_show_message_with_line ( (*this_).message_to_user,
                                                             GUI_SIMPLE_MESSAGE_TYPE_ERROR,
