@@ -2,6 +2,7 @@
 
 #include "sketch_area/gui_sketch_object_creator.h"
 #include "util/geometry/geometry_rectangle.h"
+//#include "ctrl_multi_step_changer.h"
 #include "data_table.h"
 #include "data_id.h"
 #include "trace.h"
@@ -36,19 +37,19 @@ void gui_sketch_object_creator_destroy ( gui_sketch_object_creator_t *this_ )
     TRACE_END();
 }
 
-ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_creator_t *this_,
-                                                           data_row_id_t diagram_id,
-                                                           int32_t x_order,
-                                                           int32_t y_order,
-                                                           data_row_id_t *out_diagramelement_id,
-                                                           data_row_id_t *out_classifier_id )
+u8_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_creator_t *this_,
+                                                         data_row_id_t diagram_id,
+                                                         int32_t x_order,
+                                                         int32_t y_order,
+                                                         data_row_id_t *out_diagramelement_id,
+                                                         data_row_id_t *out_classifier_id )
 {
     TRACE_BEGIN();
     assert ( NULL != out_classifier_id );
     assert ( NULL != out_diagramelement_id );
     assert ( DATA_ROW_ID_VOID != diagram_id );
 
-    ctrl_error_t c_result;
+    u8_error_t c_result;
 
     /* get classifier controller */
     ctrl_classifier_controller_t *classifier_control;
@@ -61,12 +62,12 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
     /* get type of diagram */
     data_diagram_type_t diag_type = DATA_DIAGRAM_TYPE_LIST;
     {
-        const data_error_t diag_err
+        const u8_error_t diag_err
             = data_database_reader_get_diagram_by_id( (*this_).db_reader,
                                                       diagram_id,
                                                       &((*this_).private_temp_diagram)
                                                     );
-        if ( DATA_ERROR_NONE == diag_err )
+        if ( U8_ERROR_NONE == diag_err )
         {
             diag_type = data_diagram_get_diagram_type( &((*this_).private_temp_diagram) );
             data_diagram_destroy ( &((*this_).private_temp_diagram) );
@@ -81,6 +82,11 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
     data_classifier_type_t type_of_new_classifier;
     type_of_new_classifier = data_rules_get_default_classifier_type( &((*this_).data_rules), diag_type );
 
+    /* propose a name */
+    // char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
+    // utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
+    // gui_sketch_object_creator_private_propose_classifier_name( this_, type_of_new_classifier, full_new_name );
+
     /* find a good, unused name */
     char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
     utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
@@ -96,12 +102,12 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
             utf8stringbuf_append_int( full_new_name, my_counter+search_step );
 
             /* check if that name is already in use */
-            const data_error_t exists_err
+            const u8_error_t exists_err
                 = data_database_reader_get_classifier_by_name( (*this_).db_reader,
                                                                utf8stringbuf_get_string( full_new_name ),
                                                                &((*this_).private_temp_classifier)
                                                              );
-            if ( DATA_ERROR_NONE == exists_err )
+            if ( U8_ERROR_NONE == exists_err )
             {
                 data_classifier_destroy ( &((*this_).private_temp_classifier) );
                 name_ok = false;  /* name already in use */
@@ -114,7 +120,7 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
     }
 
     /* define classifier */
-    const data_error_t d_err
+    const u8_error_t d_err
         = data_classifier_init_new ( &((*this_).private_temp_classifier),
                                      type_of_new_classifier,
                                      "",  /* stereotype */
@@ -124,18 +130,24 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
                                      y_order,
                                      y_order  /* y_order used also as list_order */
                                    );
-    if ( d_err != DATA_ERROR_NONE )
+    if ( d_err != U8_ERROR_NONE )
     {
         TSLOG_ERROR_HEX("data_classifier_init_new failed in gui_sketch_object_creator_create_classifier:",d_err);
     }
 
+    // ctrl_multi_step_changer_t multi_stepper;
+    // ctrl_multi_step_changer_init( &multi_stepper, &controller, &db_reader );
+    // u8_error_t* out_info;
+
     c_result = ctrl_classifier_controller_create_classifier ( classifier_control,
                                                               &((*this_).private_temp_classifier),
                                                               CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                               out_classifier_id
                                                             );
 
-    if ( CTRL_ERROR_NONE == c_result )
+    // ctrl_multi_step_changer_destroy( &multi_stepper );
+
+    if ( U8_ERROR_NONE == c_result )
     {
         data_diagramelement_t new_diagele;
         data_diagramelement_init_new ( &new_diagele,
@@ -154,7 +166,7 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
         /* cleanup */
         data_diagramelement_destroy ( &new_diagele );
     }
-    else if ( CTRL_ERROR_READ_ONLY_DB == c_result )
+    else if ( U8_ERROR_READ_ONLY_DB == c_result )
     {
         /* notify read-only warning to user */
         gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -170,14 +182,14 @@ ctrl_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_cre
     return c_result;
 }
 
-ctrl_error_t gui_sketch_object_creator_create_classifier_as_child ( gui_sketch_object_creator_t *this_,
-                                                                    data_row_id_t diagram_id,
-                                                                    data_row_id_t parent_classifier_id,
-                                                                    int32_t x_order,
-                                                                    int32_t y_order,
-                                                                    data_row_id_t *out_diagramelement_id,
-                                                                    data_row_id_t *out_classifier_id,
-                                                                    data_row_id_t *out_relationship_id )
+u8_error_t gui_sketch_object_creator_create_classifier_as_child ( gui_sketch_object_creator_t *this_,
+                                                                  data_row_id_t diagram_id,
+                                                                  data_row_id_t parent_classifier_id,
+                                                                  int32_t x_order,
+                                                                  int32_t y_order,
+                                                                  data_row_id_t *out_diagramelement_id,
+                                                                  data_row_id_t *out_classifier_id,
+                                                                  data_row_id_t *out_relationship_id )
 {
     TRACE_BEGIN();
     assert ( NULL != out_classifier_id );
@@ -186,7 +198,7 @@ ctrl_error_t gui_sketch_object_creator_create_classifier_as_child ( gui_sketch_o
     assert ( DATA_ROW_ID_VOID != parent_classifier_id );
     assert ( DATA_ROW_ID_VOID != diagram_id );
 
-    ctrl_error_t c_result;
+    u8_error_t c_result;
 
     c_result = gui_sketch_object_creator_create_classifier( this_,
                                                             diagram_id,
@@ -196,14 +208,14 @@ ctrl_error_t gui_sketch_object_creator_create_classifier_as_child ( gui_sketch_o
                                                             out_classifier_id
                                                           );
 
-    if ( CTRL_ERROR_NONE == c_result )
+    if ( U8_ERROR_NONE == c_result )
     {
         /* get classifier controller */
         ctrl_classifier_controller_t *classifier_control;
         classifier_control = ctrl_controller_get_classifier_control_ptr ( (*this_).controller );
 
         /* define relationship */
-        const data_error_t d_err
+        const u8_error_t d_err
             = data_relationship_init_new( &((*this_).private_temp_relationship),
                                           DATA_RELATIONSHIP_TYPE_UML_CONTAINMENT,
                                           parent_classifier_id,
@@ -214,7 +226,7 @@ ctrl_error_t gui_sketch_object_creator_create_classifier_as_child ( gui_sketch_o
                                           DATA_ROW_ID_VOID,
                                           DATA_ROW_ID_VOID
                                         );
-        if ( d_err != DATA_ERROR_NONE )
+        if ( d_err != U8_ERROR_NONE )
         {
             TSLOG_ERROR_HEX("data_relationship_init failed in gui_sketch_object_creator_create_classifier_as_child:",d_err);
         }
@@ -234,15 +246,15 @@ ctrl_error_t gui_sketch_object_creator_create_classifier_as_child ( gui_sketch_o
     return c_result;
 }
 
-ctrl_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creator_t *this_,
-                                                        data_row_id_t parent_diagram_id,
-                                                        int32_t list_order,
-                                                        data_row_id_t *out_diagram_id )
+u8_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creator_t *this_,
+                                                      data_row_id_t parent_diagram_id,
+                                                      int32_t list_order,
+                                                      data_row_id_t *out_diagram_id )
 {
     TRACE_BEGIN();
     assert ( NULL != out_diagram_id );
 
-    ctrl_error_t c_result;
+    u8_error_t c_result;
 
     ctrl_diagram_controller_t *diag_control;
     diag_control = ctrl_controller_get_diagram_control_ptr ( (*this_).controller );
@@ -252,7 +264,7 @@ ctrl_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creato
     gui_sketch_object_creator_private_propose_diagram_name( this_, new_name );
 
     /* create the diagram */
-    const data_error_t d_err
+    const u8_error_t d_err
         = data_diagram_init_new( &((*this_).private_temp_diagram),
                                  parent_diagram_id,
                                  DATA_DIAGRAM_TYPE_UML_COMPONENT_DIAGRAM,
@@ -261,7 +273,7 @@ ctrl_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creato
                                  list_order,
                                  DATA_DIAGRAM_FLAG_NONE
                                );
-    if ( d_err != DATA_ERROR_NONE )
+    if ( d_err != U8_ERROR_NONE )
     {
         TSLOG_ERROR_HEX("data_diagram_init_new failed in gui_sketch_object_creator_create_diagram:",d_err);
     }
@@ -271,7 +283,7 @@ ctrl_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creato
                                                        CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                        out_diagram_id
                                                      );
-    if ( CTRL_ERROR_READ_ONLY_DB == c_result )
+    if ( U8_ERROR_READ_ONLY_DB == c_result )
     {
         /* notify read-only warning to user */
         gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -281,7 +293,7 @@ ctrl_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creato
     }
 
     /* cleanup */
-    if ( d_err == DATA_ERROR_NONE )
+    if ( d_err == U8_ERROR_NONE )
     {
         data_diagram_destroy ( &((*this_).private_temp_diagram) );
     }
@@ -290,21 +302,21 @@ ctrl_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creato
     return c_result;
 }
 
-ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_creator_t *this_,
-                                                             data_diagram_type_t diag_type,
-                                                             data_row_id_t from_classifier_id,
-                                                             data_row_id_t from_feature_id,
-                                                             data_row_id_t to_classifier_id,
-                                                             data_row_id_t to_feature_id,
-                                                             int32_t list_order,
-                                                             data_row_id_t *out_relationship_id )
+u8_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_creator_t *this_,
+                                                           data_diagram_type_t diag_type,
+                                                           data_row_id_t from_classifier_id,
+                                                           data_row_id_t from_feature_id,
+                                                           data_row_id_t to_classifier_id,
+                                                           data_row_id_t to_feature_id,
+                                                           int32_t list_order,
+                                                           data_row_id_t *out_relationship_id )
 {
     TRACE_BEGIN();
     assert ( NULL != out_relationship_id );
     assert ( DATA_ROW_ID_VOID != from_classifier_id );
     assert ( DATA_ROW_ID_VOID != to_classifier_id );
 
-    ctrl_error_t c_result;
+    u8_error_t c_result;
 
     /* get classifier controller */
     ctrl_classifier_controller_t *classifier_control;
@@ -316,12 +328,12 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
         /* get type of from_classifier */
         data_classifier_type_t from_class_type = DATA_CLASSIFIER_TYPE_CLASS;
         {
-            const data_error_t clsfy_err
+            const u8_error_t clsfy_err
                 = data_database_reader_get_classifier_by_id( (*this_).db_reader,
                                                              from_classifier_id,
                                                              &((*this_).private_temp_classifier)
                                                            );
-            if ( DATA_ERROR_NONE == clsfy_err )
+            if ( U8_ERROR_NONE == clsfy_err )
             {
                 from_class_type = data_classifier_get_main_type( &((*this_).private_temp_classifier) );
                 data_classifier_destroy ( &((*this_).private_temp_classifier) );
@@ -336,12 +348,12 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
         data_feature_type_t from_feature_type = DATA_FEATURE_TYPE_VOID;
         if ( from_feature_id != DATA_ROW_ID_VOID )
         {
-            const data_error_t feat_err
+            const u8_error_t feat_err
                 = data_database_reader_get_feature_by_id( (*this_).db_reader,
                                                           from_feature_id,
                                                           &((*this_).private_temp_feature)
                                                         );
-            if ( DATA_ERROR_NONE == feat_err )
+            if ( U8_ERROR_NONE == feat_err )
             {
                 from_feature_type = data_feature_get_main_type( &((*this_).private_temp_feature) );
                 data_feature_destroy ( &((*this_).private_temp_feature) );
@@ -355,7 +367,7 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
     }
 
     /* define relationship struct */
-    const data_error_t d_err
+    const u8_error_t d_err
         = data_relationship_init_new( &((*this_).private_temp_relationship),
                                       new_rel_type,
                                       from_classifier_id,
@@ -366,7 +378,7 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
                                       from_feature_id,
                                       to_feature_id
                                     );
-    if ( d_err != DATA_ERROR_NONE )
+    if ( d_err != U8_ERROR_NONE )
     {
         TSLOG_ERROR_HEX("data_relationship_init failed in gui_sketch_object_creator_create_relationship:",d_err);
     }
@@ -385,7 +397,7 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                                    out_relationship_id
                                                                  );
-        if ( CTRL_ERROR_READ_ONLY_DB == c_result )
+        if ( U8_ERROR_READ_ONLY_DB == c_result )
         {
             /* notify read-only warning to user */
             gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -401,7 +413,7 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
                                                  GUI_SIMPLE_MESSAGE_TYPE_ERROR,
                                                  GUI_SIMPLE_MESSAGE_CONTENT_NO_RELATIONSHIPS
                                                );
-        c_result = CTRL_ERROR_DIAGRAM_HIDES_RELATIONSHIPS;
+        c_result = U8_ERROR_DIAGRAM_HIDES_RELATIONSHIPS;
     }
 
     /* cleanup */
@@ -411,18 +423,18 @@ ctrl_error_t gui_sketch_object_creator_create_relationship ( gui_sketch_object_c
     return c_result;
 }
 
-ctrl_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creator_t *this_,
-                                                        data_diagram_type_t diag_type,
-                                                        data_row_id_t parent_classifier_id,
-                                                        int32_t std_list_order,
-                                                        int32_t port_list_order,
-                                                        data_row_id_t *out_feature_id )
+u8_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creator_t *this_,
+                                                      data_diagram_type_t diag_type,
+                                                      data_row_id_t parent_classifier_id,
+                                                      int32_t std_list_order,
+                                                      int32_t port_list_order,
+                                                      data_row_id_t *out_feature_id )
 {
     TRACE_BEGIN();
     assert ( NULL != out_feature_id );
     assert ( DATA_ROW_ID_VOID != parent_classifier_id );
 
-    ctrl_error_t c_result;
+    u8_error_t c_result;
 
     /* get classifier controller */
     ctrl_classifier_controller_t *classifier_control;
@@ -431,12 +443,12 @@ ctrl_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creato
     /* get type of parent classifier */
     data_classifier_type_t parent_class_type = DATA_CLASSIFIER_TYPE_CLASS;
     {
-        const data_error_t clsfy_err
+        const u8_error_t clsfy_err
             = data_database_reader_get_classifier_by_id( (*this_).db_reader,
                                                          parent_classifier_id,
                                                          &((*this_).private_temp_classifier)
                                                        );
-        if ( DATA_ERROR_NONE == clsfy_err )
+        if ( U8_ERROR_NONE == clsfy_err )
         {
             parent_class_type = data_classifier_get_main_type( &((*this_).private_temp_classifier) );
             data_classifier_destroy( &((*this_).private_temp_classifier) );
@@ -471,21 +483,19 @@ ctrl_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creato
     /* find a good default name */
     char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
     utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
-    char newtype_buf[DATA_CLASSIFIER_MAX_STEREOTYPE_SIZE];
-    utf8stringbuf_t full_new_type = UTF8STRINGBUF( newtype_buf );
-    gui_sketch_object_creator_private_propose_feature_name( this_, new_feature_type, full_new_name, full_new_type );
+    gui_sketch_object_creator_private_propose_feature_name( this_, new_feature_type, full_new_name );
 
     /* define feature struct */
-    const data_error_t data_err
+    const u8_error_t data_err
         = data_feature_init_new( &((*this_).private_temp_feature),
                                  new_feature_type,
                                  parent_classifier_id,
                                  utf8stringbuf_get_string( full_new_name ),
-                                 utf8stringbuf_get_string( full_new_type ),
+                                 "",  /* type/value */
                                  "",
                                  list_order
                                );
-    if ( data_err != DATA_ERROR_NONE )
+    if ( data_err != U8_ERROR_NONE )
     {
         TSLOG_ERROR_HEX("data_feature_init failed in gui_sketch_object_creator_create_feature:",data_err);
     }
@@ -506,7 +516,7 @@ ctrl_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creato
                                                               CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                               out_feature_id
                                                             );
-        if ( CTRL_ERROR_READ_ONLY_DB == c_result )
+        if ( U8_ERROR_READ_ONLY_DB == c_result )
         {
             /* notify read-only warning to user */
             gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -522,7 +532,7 @@ ctrl_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creato
                                                  GUI_SIMPLE_MESSAGE_TYPE_ERROR,
                                                  GUI_SIMPLE_MESSAGE_CONTENT_FEATURELESS_CLASSIFIER
                                                );
-        c_result = CTRL_ERROR_CLASSIFIER_REFUSES_FEATURE;
+        c_result = U8_ERROR_CLASSIFIER_REFUSES_FEATURE;
     }
     else
     {
@@ -531,7 +541,7 @@ ctrl_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creato
                                                  GUI_SIMPLE_MESSAGE_TYPE_ERROR,
                                                  GUI_SIMPLE_MESSAGE_CONTENT_NO_FEATURES
                                                );
-        c_result = CTRL_ERROR_DIAGRAM_HIDES_FEATURES;
+        c_result = U8_ERROR_DIAGRAM_HIDES_FEATURES;
     }
 
     /* cleanup */
@@ -699,16 +709,12 @@ void gui_sketch_object_creator_private_propose_classifier_name( gui_sketch_objec
 
 void gui_sketch_object_creator_private_propose_feature_name( gui_sketch_object_creator_t *this_,
                                                              data_feature_type_t f_type,
-                                                             utf8stringbuf_t out_name,
-                                                             utf8stringbuf_t out_type )
+                                                             utf8stringbuf_t out_name )
 {
     static int cycle_names = 0;
     static char *(PROPERTY_NAMES[8]) = {"new_state","new_run_mode","new_error_code","new_color","new_name","new_type","new_size","new_weight"};
-    static char *(PROPERTY_TYPES[8]) = {"uint32_t","enum","struct","uint8_t[4]","char[48]","","size_t","double"};
     static char *(OPERATION_NAMES[8]) = {"new_start","new_stop","new_pause","new_resume","new_get_state","new_handle_event","new_set_color","new_is_valid"};
-    static char *(OPERATION_TYPES[8]) = {"uint32_t()(void)","uint32_t(*)(enum)","","","enum","","uint32_t(*)(uint8_t[4])","bool"};
     static char *(PORT_NAMES[8]) = {"new_in_a","new_in_b","new_in_c","new_out_a","new_out_b","new_out_c","new_out_error","new_in_reset"};
-    static char *(PORT_TYPES[8]) = {"","signal","uint16_t","IP-socket","signal","","","bool"};
     static char *(IO_PORT_NAMES[8]) = {"new_order","new_item","new_error","new_report","new_audio_file","new_video_file","new_plan","new_status"};
     static char *(IF_NAMES[8]) = {"New Auth_IF","New Log_IF","New Trace_IF","New Update_IF","New Sync_IF","New Link_IF","New Alive_IF","New Power_IF"};
     static char *(ENTRY_NAMES[8]) = {"new_again","new_first_time","new_error_case","new_std_entry","new_retries_exceeded","new_debug","new_rookie_mode","new_last_try"};
@@ -721,68 +727,58 @@ void gui_sketch_object_creator_private_propose_feature_name( gui_sketch_object_c
         case DATA_FEATURE_TYPE_PROPERTY:
         {
             utf8stringbuf_copy_str( out_name, PROPERTY_NAMES[cycle_names&0x07] );
-            utf8stringbuf_copy_str( out_type, PROPERTY_TYPES[cycle_names&0x07] );
         }
         break;
 
         case DATA_FEATURE_TYPE_OPERATION:
         {
             utf8stringbuf_copy_str( out_name, OPERATION_NAMES[cycle_names&0x07] );
-            utf8stringbuf_copy_str( out_type, OPERATION_TYPES[cycle_names&0x07] );
         }
         break;
 
         case DATA_FEATURE_TYPE_PORT:
         {
             utf8stringbuf_copy_str( out_name, PORT_NAMES[cycle_names&0x07] );
-            utf8stringbuf_copy_str( out_type, PORT_TYPES[cycle_names&0x07] );
         }
         break;
 
         case DATA_FEATURE_TYPE_LIFELINE:
         {
             utf8stringbuf_clear( out_name );
-            utf8stringbuf_clear( out_type );
         }
         break;
 
         case DATA_FEATURE_TYPE_PROVIDED_INTERFACE:
         {
             utf8stringbuf_copy_str( out_name, IF_NAMES[cycle_names&0x07] );
-            utf8stringbuf_clear( out_type );
         }
         break;
 
         case DATA_FEATURE_TYPE_REQUIRED_INTERFACE:
         {
             utf8stringbuf_copy_str( out_name, IF_NAMES[cycle_names&0x07] );
-            utf8stringbuf_clear( out_type );
         }
         break;
         case DATA_FEATURE_TYPE_IN_PORT_PIN:
         case DATA_FEATURE_TYPE_OUT_PORT_PIN:
         {
             utf8stringbuf_copy_str( out_name, IO_PORT_NAMES[cycle_names&0x07] );
-            utf8stringbuf_clear( out_type );
         }
         break;
         case DATA_FEATURE_TYPE_ENTRY:
         {
             utf8stringbuf_copy_str( out_name, ENTRY_NAMES[cycle_names&0x07] );
-            utf8stringbuf_clear( out_type );
         }
         break;
         case DATA_FEATURE_TYPE_EXIT:
         {
             utf8stringbuf_copy_str( out_name, EXIT_NAMES[cycle_names&0x07] );
-            utf8stringbuf_clear( out_type );
         }
         break;
         default:
         {
             TSLOG_ERROR("data_feature_type_t out of range in gui_sketch_object_creator_private_propose_feature_name");
             utf8stringbuf_clear( out_name );
-            utf8stringbuf_clear( out_type );
         }
         break;
     }
