@@ -18,6 +18,7 @@
 #define JSON_CONSTANTS_TAB "  "
 #define JSON_CONSTANTS_QUOTE "\""
 #define JSON_CONSTANTS_DEF ": "
+#define JSON_CONSTANTS_DEF_NL ":\n"
 #define JSON_CONSTANTS_BEGIN_ARRAY "["
 #define JSON_CONSTANTS_END_ARRAY "]"
 #define JSON_CONSTANTS_NEXT_NL ",\n"
@@ -54,24 +55,31 @@
 #define JSON_CONSTANTS_KEY_DIAGRAM "diagram"
 #define JSON_CONSTANTS_KEY_DIAGRAM_ID "id"
 #define JSON_CONSTANTS_KEY_DIAGRAM_PARENT_ID "parent_id"
+#define JSON_CONSTANTS_KEY_DIAGRAM_PARENT_NAME "parent_name"
 #define JSON_CONSTANTS_KEY_DIAGRAM_PARENT "parent"
 #define JSON_CONSTANTS_KEY_DIAGRAM_DIAGRAM_TYPE "diagram_type"
+#define JSON_CONSTANTS_KEY_DIAGRAM_DIAGRAM_TYPE_NAME "type"
 #define JSON_CONSTANTS_KEY_DIAGRAM_NAME "name"
 #define JSON_CONSTANTS_KEY_DIAGRAM_DESCRIPTION "description"
 #define JSON_CONSTANTS_KEY_DIAGRAM_LIST_ORDER "list_order"
 #define JSON_CONSTANTS_KEY_DIAGRAM_DISPLAY_FLAGS "display_flags"
+#define JSON_CONSTANTS_KEY_DIAGRAM_DISPLAY_FLAG_NAMES "display_tags"
 #define JSON_CONSTANTS_KEY_DIAGRAM_ELEMENTS "diagramelements"
 
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_ID "id"
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DIAGRAM_ID "diagram_id"
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_CLASSIFIER_ID "classifier_id"
+#define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_CLASSIFIER_NAME "classifier_name"
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_FOCUSED_FEATURE_ID "focused_feature_id"
+#define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_FOCUSED_FEATURE_NAME "focused_feature_name"
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DISPLAY_FLAGS "display_flags"
+#define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_DISPLAY_FLAG_NAMES "display_tags"
 #define JSON_CONSTANTS_KEY_DIAGRAMELEMENT_NODE "node"
 
 #define JSON_CONSTANTS_KEY_CLASSIFIER "classifier"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_ID "id"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_MAIN_TYPE "main_type"
+#define JSON_CONSTANTS_KEY_CLASSIFIER_MAIN_TYPE_NAME "type"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_STEREOTYPE "stereotype"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_NAME "name"
 #define JSON_CONSTANTS_KEY_CLASSIFIER_DESCRIPTION "description"
@@ -82,6 +90,7 @@
 
 #define JSON_CONSTANTS_KEY_FEATURE_ID "id"
 #define JSON_CONSTANTS_KEY_FEATURE_MAIN_TYPE "main_type"
+#define JSON_CONSTANTS_KEY_FEATURE_MAIN_TYPE_NAME "type"
 #define JSON_CONSTANTS_KEY_FEATURE_KEY "key"
 #define JSON_CONSTANTS_KEY_FEATURE_VALUE "value"
 #define JSON_CONSTANTS_KEY_FEATURE_DESCRIPTION "description"
@@ -100,6 +109,7 @@
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_TO_FEATURE_KEY "to_feature_key"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_TO_NODE "to_node"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_MAIN_TYPE "main_type"
+#define JSON_CONSTANTS_KEY_RELATIONSHIP_MAIN_TYPE_NAME "type"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_NAME "name"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_DESCRIPTION "description"
 #define JSON_CONSTANTS_KEY_RELATIONSHIP_LIST_ORDER "list_order"
