@@ -16,7 +16,7 @@ static void test_skip_number(void);
 static void test_parse(void);
 
 
-test_suite_t json_token_reader_test_get_list(void)
+test_suite_t json_token_reader_test_get_suite(void)
 {
     test_suite_t result;
     test_suite_init( &result, "json_token_reader_test", &set_up, &tear_down );
@@ -99,7 +99,7 @@ static void test_is_value_end(void)
 
 static void test_get_value_type(void)
 {
-    data_error_t test_err;
+    u8_error_t test_err;
     universal_memory_input_stream_t test_input;
     json_value_type_t value_type;
 
@@ -111,7 +111,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 1, json_token_reader_get_input_pos( &tok ) );  /* there is a whitespace in front of the value */
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_OBJECT, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_ARRAY */
     const char test_str_2[4] = " [\t";
@@ -121,7 +121,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 1, json_token_reader_get_input_pos( &tok ) );  /* there is a whitespace in front of the value */
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_ARRAY, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_NUMBER */
     const char test_str_3[4] = "-12";
@@ -131,7 +131,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 0, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_NUMBER, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_STRING */
     const char test_str_4[4] = "\"s\"";
@@ -141,7 +141,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 0, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_STRING, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_NULL */
     const char test_str_5[4] = "nul";
@@ -151,7 +151,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 0, json_token_reader_get_input_pos( &tok ) );  /* there is a whitespace in front of the value */
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_NULL, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_BOOLEAN */
     const char test_str_6[4] = "fal";
@@ -161,7 +161,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 0, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_BOOLEAN, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_BOOLEAN */
     const char test_str_7[4] = "\n\tt";
@@ -171,7 +171,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 2, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_BOOLEAN, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
 
     /* JSON_VALUE_TYPE_UNDEF */
     const char test_str_8[4] = " ]}";
@@ -181,7 +181,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 1, json_token_reader_get_input_pos( &tok ) );  /* there is a whitespace in front of the not-value */
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_UNDEF, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_PARSER_STRUCTURE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_PARSER_STRUCTURE, test_err );
 
     /* EOF */
     const char test_str_9[4] = "  \r";
@@ -191,7 +191,7 @@ static void test_get_value_type(void)
     test_err = json_token_reader_get_value_type ( &tok, &value_type );
     TEST_ASSERT_EQUAL_INT( 3, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( JSON_VALUE_TYPE_UNDEF, value_type );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_PARSER_STRUCTURE, test_err );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_PARSER_STRUCTURE, test_err );
 
     json_token_reader_destroy( &tok );
     universal_memory_input_stream_destroy( &test_input );
@@ -199,7 +199,7 @@ static void test_get_value_type(void)
 
 static void test_parse_string(void)
 {
-   data_error_t test_err;
+   u8_error_t test_err;
    const char test_str[6][17] = {
         "\"\'\'simple    \'\'\"",
         "\"\\\\mixed    \\n\'\"",
@@ -229,7 +229,7 @@ static void test_parse_string(void)
         json_token_reader_reinit( &tok, universal_memory_input_stream_get_input_stream( &test_input ) );
 
         test_err = json_token_reader_read_string_value( &tok, parsed_str );
-        TEST_ASSERT_EQUAL_INT( (index>=4)?DATA_ERROR_LEXICAL_STRUCTURE:DATA_ERROR_NONE, test_err );
+        TEST_ASSERT_EQUAL_INT( (index>=4)?U8_ERROR_LEXICAL_STRUCTURE:U8_ERROR_NONE, test_err );
         TEST_ASSERT_EQUAL_INT( 1, utf8stringbuf_equals_str( parsed_str, expect_str[index] ) );
     }
 
@@ -239,7 +239,7 @@ static void test_parse_string(void)
 
 static void test_parse_integer(void)
 {
-    data_error_t test_err;
+    u8_error_t test_err;
     const char test_str[8][16] = {
         "  0",
         "  00",
@@ -264,7 +264,7 @@ static void test_parse_integer(void)
         json_token_reader_reinit( &tok, universal_memory_input_stream_get_input_stream( &test_input ) );
 
         test_err = json_token_reader_read_int_value( &tok, &int_result );
-        TEST_ASSERT_EQUAL_INT( (err_results[index]!=0)?DATA_ERROR_LEXICAL_STRUCTURE:DATA_ERROR_NONE, test_err );
+        TEST_ASSERT_EQUAL_INT( (err_results[index]!=0)?U8_ERROR_LEXICAL_STRUCTURE:U8_ERROR_NONE, test_err );
         TEST_ASSERT_EQUAL_INT( int_results[index], int_result );
         printf("parsed: %" PRId64 "\n",int_result);
     }
@@ -275,7 +275,7 @@ static void test_parse_integer(void)
 
 static void test_skip_number(void)
 {
-    data_error_t test_err;
+    u8_error_t test_err;
     const char test_str[8][16] = {
         "0.0000 ",
         "000000 ",
@@ -297,7 +297,7 @@ static void test_skip_number(void)
         json_token_reader_reinit( &tok, universal_memory_input_stream_get_input_stream( &test_input ) );
 
         test_err = json_token_reader_private_skip_number( &tok );
-        TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, test_err );
+        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, test_err );
         TEST_ASSERT_EQUAL_INT( 6, json_token_reader_get_input_pos( &tok ) );  /* all numbers have 6 digits */
     }
 
@@ -323,7 +323,7 @@ static void test_parse(void)
         "\n  ]"
         "\n}"
         "\n";
-    data_error_t res;
+    u8_error_t res;
     bool cond;
     char my_buf[32];
     utf8stringbuf_t my_string = UTF8STRINGBUF( my_buf );
@@ -335,159 +335,159 @@ static void test_parse(void)
     json_token_reader_init( &tok, universal_memory_input_stream_get_input_stream( &test_input ) );
 
     res = json_token_reader_expect_begin_object ( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 2, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_check_end_object ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 5, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( false, cond );
 
     res = json_token_reader_read_member_name ( &tok, my_string );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 11, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( 0, strcmp( "data", utf8stringbuf_get_string(my_string)) );
 
     res = json_token_reader_expect_name_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 12, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_expect_begin_array ( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 14, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_check_end_array ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 19, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( false, cond );
 
     res = json_token_reader_expect_begin_object ( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 20, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_check_end_object ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 27, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( false, cond );
 
     res = json_token_reader_read_member_name ( &tok, my_string );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 39, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( 0, strcmp( "classifier", utf8stringbuf_get_string(my_string)) );
 
     res = json_token_reader_expect_name_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 41, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_expect_begin_object ( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 43, json_token_reader_get_input_pos( &tok ) );
 
     /* skip test for end object here */
 
     res = json_token_reader_read_member_name ( &tok, my_string );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 56, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( 0, strcmp( "id", utf8stringbuf_get_string(my_string)) );
 
     res = json_token_reader_expect_name_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 61, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_read_int_value ( &tok, &my_int );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 64, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( -99, my_int );
 
     /* skip test for end object here */
 
     res = json_token_reader_expect_value_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 65, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_read_member_name ( &tok, my_string );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 85, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( 0, strcmp( "main_type", utf8stringbuf_get_string(my_string)) );
 
     res = json_token_reader_expect_name_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 91, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_read_number_value ( &tok, &my_double );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NOT_YET_IMPLEMENTED, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NOT_YET_IMPLEMENTED, res );
     TEST_ASSERT_EQUAL_INT( 99, json_token_reader_get_input_pos( &tok ) );
 
     /* skip test for end object here */
 
     res = json_token_reader_read_member_name ( &tok, my_string );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 129, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( 0, strcmp( "stereotype\r/\"\\", utf8stringbuf_get_string(my_string)) );
 
     res = json_token_reader_expect_name_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 130, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_read_string_value ( &tok, my_string );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 149, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( 0, strcmp( "\f\n\t\b\r/\"\\", utf8stringbuf_get_string(my_string)) );
 
     res = json_token_reader_check_end_object ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 157, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( true, cond );
 
     res = json_token_reader_check_end_object ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 163, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( true, cond );
 
     /* skip test for end array here */
 
     res = json_token_reader_expect_value_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 164, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_expect_null_value ( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 173, json_token_reader_get_input_pos( &tok ) );
 
     /* skip test for end array here */
 
     res = json_token_reader_expect_value_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 174, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_read_boolean_value ( &tok, &my_bool );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 183, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( true, my_bool );
 
     /* skip test for end array here */
 
     res = json_token_reader_expect_value_separator( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 184, json_token_reader_get_input_pos( &tok ) );
 
     res = json_token_reader_read_boolean_value ( &tok, &my_bool );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 194, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( false, my_bool );
 
     res = json_token_reader_check_end_array ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 198, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( true, cond );
 
     res = json_token_reader_check_end_object ( &tok, &cond );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 200, json_token_reader_get_input_pos( &tok ) );
     TEST_ASSERT_EQUAL_INT( true, cond );
 
     res = json_token_reader_expect_eof ( &tok );
-    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, res );
+    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, res );
     TEST_ASSERT_EQUAL_INT( 201, json_token_reader_get_input_pos( &tok ) );
 
     json_token_reader_destroy( &tok );
