@@ -10,7 +10,7 @@
 
 #include "test_suite.h"
 
-test_suite_t json_token_reader_test_get_list(void);
+test_suite_t json_token_reader_test_get_suite(void);
 
 #endif  /* JSON_TOKENIZER_TEST_H */
 
