@@ -10,7 +10,7 @@
 
 #include "test_suite.h"
 
-test_suite_t md_filter_test_get_list(void);
+test_suite_t md_filter_test_get_suite(void);
 
 #endif  /* MD_FILTER_TEST_H */
 
