@@ -2,7 +2,6 @@
 
 #include "main.h"
 #include "main_commands.h"
-#include "io_file_format.h"
 #include "trace.h"
 #include "tslog.h"
 #include "meta/meta_info.h"
@@ -19,19 +18,21 @@
 
 static const char *const MAIN_HELP
     = "\nUsage:\n"
-    "    -h for help\n"
-    "    -v for version\n"
-    "    -e <database_file> <export_format> <target_directory> to export all diagrams\n"
-    "    -i <database_file> json            <input_file>       to import elements\n"
-    "    -u <database_file> to use/create a database file\n"
-    "    -g <database_file> to upgrade the database tables from version 1.32.1 and older\n"
-    "    -t <database_file> to test the database file\n"
-    "    -r <database_file> to test and repair the database file\n";
+    "    -h : for help\n"
+    "    -v : for version\n"
+    "    -e <database_file> <export_format> <export_directory> : to export all diagrams,\n"
+    "       export_format: docbook|json|pdf|png|ps|svg|txt|xhtml|xmi\n"
+    "    -i <database_file> <import_mode>   <json_input_file>  : to import elements,\n"
+    "       import_mode: check|update\n"
+    "    -u <database_file> : to use/create a database file\n"
+    /*"    -g <database_file> to upgrade the database tables from version 1.32.1 and older\n"*/
+    "    -t <database_file> : to test the database file\n"
+    "    -r <database_file> : to test and repair the database file\n";
 
 int main (int argc, char *argv[]) {
     TRACE_BEGIN();
     TRACE_TIMESTAMP();
-    int exit_code = 0;
+    u8_error_t exit_code = U8_ERROR_NONE;
     TSLOG_INIT(META_INFO_PROGRAM_ID_STR);
     char *database_file = NULL;
     char *export_directory = NULL;
@@ -43,7 +44,7 @@ int main (int argc, char *argv[]) {
     bool do_upgrade = false;
     bool do_import = false;
     io_file_format_t export_format = 0;
-    io_file_format_t import_format = 0;
+    io_import_mode_t import_mode = 0;
     universal_stream_output_stream_t out_stream;
     universal_stream_output_stream_init( &out_stream, stdout );
     universal_utf8_writer_t writer;
@@ -103,7 +104,7 @@ int main (int argc, char *argv[]) {
         if ( utf8string_equals_str( argv[1], "-i" ) )
         {
             database_file = argv[2];
-            import_format = main_private_get_selected_format(argv[3]);
+            import_mode = main_private_get_selected_mode(argv[3]);
             import_file = argv[4];
             do_not_start = true;
             do_import = true;
@@ -133,7 +134,7 @@ int main (int argc, char *argv[]) {
 
         if ( do_import )
         {
-            exit_code |= main_commands_import( &commands, database_file, import_format, import_file, &writer );
+            exit_code |= main_commands_import( &commands, database_file, import_mode, import_file, &writer );
         }
 
         /* run program */
@@ -149,8 +150,9 @@ int main (int argc, char *argv[]) {
 
     TSLOG_DESTROY();
     TRACE_TIMESTAMP();
-    TRACE_END_ERR(exit_code);
-    return exit_code;
+    int exit_byte = ((exit_code >> 24)|(exit_code >> 16)|(exit_code >> 8)|(exit_code))&0xff;
+    TRACE_END_ERR(exit_byte);
+    return exit_byte;
 }
 
 io_file_format_t main_private_get_selected_format( char *arg_fmt )
@@ -159,7 +161,15 @@ io_file_format_t main_private_get_selected_format( char *arg_fmt )
     assert( arg_fmt != NULL );
     io_file_format_t result = 0;
 
-    if ( utf8string_equals_str( arg_fmt, "pdf" ) )
+    if ( utf8string_equals_str( arg_fmt, "docbook" ) )
+    {
+        result = IO_FILE_FORMAT_DOCBOOK;
+    }
+    else if ( utf8string_equals_str( arg_fmt, "json" ) )
+    {
+        result = IO_FILE_FORMAT_JSON;
+    }
+    else if ( utf8string_equals_str( arg_fmt, "pdf" ) )
     {
         result = IO_FILE_FORMAT_PDF;
     }
@@ -179,10 +189,6 @@ io_file_format_t main_private_get_selected_format( char *arg_fmt )
     {
         result = IO_FILE_FORMAT_TXT;
     }
-    else if ( utf8string_equals_str( arg_fmt, "docbook" ) )
-    {
-        result = IO_FILE_FORMAT_DOCBOOK;
-    }
     else if ( utf8string_equals_str( arg_fmt, "xhtml" ) )
     {
         result = IO_FILE_FORMAT_XHTML;
@@ -191,9 +197,24 @@ io_file_format_t main_private_get_selected_format( char *arg_fmt )
     {
         result = IO_FILE_FORMAT_XMI2;
     }
-    else if ( utf8string_equals_str( arg_fmt, "json" ) )
+
+    TRACE_END();
+    return result;
+}
+
+io_import_mode_t main_private_get_selected_mode( char *arg_fmt )
+{
+    TRACE_BEGIN();
+    assert( arg_fmt != NULL );
+    io_import_mode_t result = IO_IMPORT_MODE_CHECK;
+
+    if ( utf8string_equals_str( arg_fmt, "check" ) )
     {
-        result = IO_FILE_FORMAT_JSON;
+        result = IO_IMPORT_MODE_CHECK;
+    }
+    else if ( utf8string_equals_str( arg_fmt, "update" ) )
+    {
+        result = IO_IMPORT_MODE_CREATE|IO_IMPORT_MODE_LINK;
     }
 
     TRACE_END();
