@@ -1,32 +1,40 @@
 /* File: test_main.c; Copyright and License: see below */
 
+/* data */
 #include "unit/data_change_notifier_test.h"
 #include "unit/data_small_set_test.h"
 #include "unit/data_uuid_test.h"
 #include "unit/data_rules_test.h"
 #include "unit/data_database_listener_test.h"
 #include "integration/data_database_reader_test.h"
+/* ctrl */
 #include "unit/ctrl_diagram_controller_test.h"
 #include "unit/ctrl_controller_test.h"
+#include "unit/ctrl_multi_step_changer_test.h"
 #include "unit/ctrl_classifier_controller_test.h"
 #include "unit/ctrl_consistency_checker_test.h"
 #include "unit/ctrl_undo_redo_list_test.h"
 #include "unit/ctrl_diagram_policy_enforcer_test.h"
 #include "unit/ctrl_classifier_policy_enforcer_test.h"
+/* pencil */
 #include "unit/geometry_rectangle_test.h"
 #include "unit/geometry_connector_test.h"
 #include "unit/geometry_non_linear_scale_test.h"
-#include "unit/gui_sketch_nav_tree_test.h"
-#include "unit/txt_writer_test.h"
-#include "unit/json_token_reader_test.h"
-#include "unit/json_import_to_database_test.h"
-#include "unit/md_filter_test.h"
-#include "integration/io_export_model_traversal_test.h"
 #include "unit/draw_classifier_contour_test.h"
 #include "unit/pencil_layout_data_test.h"
 #include "unit/pencil_classifier_composer_test.h"
 #include "integration/pencil_layouter_test.h"
 #include "integration/pencil_diagram_maker_test.h"
+/* gui */
+#include "unit/gui_sketch_nav_tree_test.h"
+/* io */
+#include "unit/txt_writer_test.h"
+#include "unit/json_token_reader_test.h"
+#include "unit/md_filter_test.h"
+#include "unit/io_import_elements_test.h"
+#include "integration/io_importer_test.h"
+#include "integration/io_export_model_traversal_test.h"
+/* universal */
 #include "unit/universal_array_index_sorter_test.h"
 #include "unit/universal_array_list_test.h"
 #include "unit/universal_memory_output_stream_test.h"
@@ -36,6 +44,7 @@
 #include "unit/universal_buffer_output_stream_test.h"
 #include "unit/universal_memory_arena_test.h"
 #include "unit/universal_arena_list_test.h"
+/* utf8stringbuf */
 #include "unit/utf8stringbuf_test.h"
 #include "unit/utf8codepoint_test.h"
 #include "unit/utf8codepointiterator_test.h"
@@ -43,11 +52,12 @@
 /* #include "unit/utf8stringbuf_performance.h" -- performance measurements are not reliable - depend on system config+load */
 #include "unit/utf8stringview_test.h"
 #include "unit/utf8stringviewiterator_test.h"
+#include "util/string/utf8string.h"
+/* TEST_ENVIRONMENT */
 #include "trace.h"
 #include "tslog.h"
 #include "meta/meta_info.h"
 #include "meta/meta_version.h"
-#include "util/string/utf8string.h"
 #include "test_runner.h"
 #include <gtk/gtk.h>
 #include <stdbool.h>
@@ -116,57 +126,73 @@ int main (int argc, char *argv[]) {
     test_runner_t runner;
     test_runner_init ( &runner );
 
-    /* unit-tests */
+    /* unit-tests test single software units and try to cover all control flows */
     if ( do_unit_tests )
     {
-        test_runner_run_suite( &runner, data_small_set_test_get_list() );
-        test_runner_run_suite( &runner, data_rules_test_get_list() );
-        test_runner_run_suite( &runner, data_uuid_test_get_list() );
-        test_runner_run_suite( &runner, data_change_notifier_test_get_list() );
-        test_runner_run_suite( &runner, data_database_listener_test_get_list() );
-        test_runner_run_suite( &runner, geometry_rectangle_test_get_list() );
-        test_runner_run_suite( &runner, geometry_connector_test_get_list() );
-        test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_list() );
-        test_runner_run_suite( &runner, txt_writer_test_get_list() );
-        test_runner_run_suite( &runner, json_token_reader_test_get_list() );
-        test_runner_run_suite( &runner, draw_classifier_contour_test_get_list() );
-        test_runner_run_suite( &runner, pencil_classifier_composer_test_get_list() );
-        test_runner_run_suite( &runner, pencil_layout_data_test_get_list() );
-        test_runner_run_suite( &runner, universal_array_index_sorter_test_get_list() );
-        test_runner_run_suite( &runner, universal_array_list_test_get_list() );
-        test_runner_run_suite( &runner, universal_memory_output_stream_test_get_list() );
-        test_runner_run_suite( &runner, universal_escaping_output_stream_test_get_list() );
-        test_runner_run_suite( &runner, universal_memory_input_stream_test_get_list() );
-        test_runner_run_suite( &runner, universal_buffer_input_stream_test_get_list() );
-        test_runner_run_suite( &runner, universal_buffer_output_stream_test_get_list() );
-        test_runner_run_suite( &runner, universal_memory_arena_test_get_list() );
-        test_runner_run_suite( &runner, universal_arena_list_test_get_list() );
-        test_runner_run_suite( &runner, utf8codepoint_test_get_list() );
-        test_runner_run_suite( &runner, utf8codepointiterator_test_get_list() );
-        test_runner_run_suite( &runner, utf8stringbuf_test_get_list() );
-        test_runner_run_suite( &runner, utf8string_test_get_list() );
+        /* data */
+        test_runner_run_suite( &runner, data_small_set_test_get_suite() );
+        test_runner_run_suite( &runner, data_rules_test_get_suite() );
+        test_runner_run_suite( &runner, data_uuid_test_get_suite() );
+        test_runner_run_suite( &runner, data_change_notifier_test_get_suite() );
+        test_runner_run_suite( &runner, data_database_listener_test_get_suite() );
+        /* ctrl */
+        /* pencil */
+        test_runner_run_suite( &runner, geometry_rectangle_test_get_suite() );
+        test_runner_run_suite( &runner, geometry_connector_test_get_suite() );
+        test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_suite() );
+        test_runner_run_suite( &runner, draw_classifier_contour_test_get_suite() );
+        test_runner_run_suite( &runner, pencil_classifier_composer_test_get_suite() );
+        test_runner_run_suite( &runner, pencil_layout_data_test_get_suite() );
+        /* gui */
+        /* io */
+        test_runner_run_suite( &runner, txt_writer_test_get_suite() );
+        test_runner_run_suite( &runner, json_token_reader_test_get_suite() );
+        test_runner_run_suite( &runner, io_import_elements_test_get_suite() );
+        /* universal */
+        test_runner_run_suite( &runner, universal_array_index_sorter_test_get_suite() );
+        test_runner_run_suite( &runner, universal_array_list_test_get_suite() );
+        test_runner_run_suite( &runner, universal_memory_output_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_escaping_output_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_memory_input_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_buffer_input_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_buffer_output_stream_test_get_suite() );
+        test_runner_run_suite( &runner, universal_memory_arena_test_get_suite() );
+        test_runner_run_suite( &runner, universal_arena_list_test_get_suite() );
+        /* utf8stringbuf */
+        test_runner_run_suite( &runner, utf8codepoint_test_get_suite() );
+        test_runner_run_suite( &runner, utf8codepointiterator_test_get_suite() );
+        test_runner_run_suite( &runner, utf8stringbuf_test_get_suite() );
+        test_runner_run_suite( &runner, utf8string_test_get_suite() );
         /* test_runner_run_suite( &runner, utf8stringbuf_performance_get_list() ); -- performance measurements are not reliable - depend on system config+load */
-        test_runner_run_suite( &runner, utf8stringview_test_get_list() );
-        test_runner_run_suite( &runner, utf8stringviewiterator_test_get_list() );
-        test_runner_run_suite( &runner, gui_sketch_nav_tree_test_get_list() );
+        test_runner_run_suite( &runner, utf8stringview_test_get_suite() );
+        test_runner_run_suite( &runner, utf8stringviewiterator_test_get_suite() );
+        test_runner_run_suite( &runner, gui_sketch_nav_tree_test_get_suite() );
     }
 
-    /* integration tests which involve multiple software units */
+    /* integration tests test multiple software units and their interactions */
     if ( do_integration_tests )
     {
-        test_runner_run_suite( &runner, data_database_reader_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_controller_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_diagram_controller_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_classifier_controller_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_consistency_checker_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_undo_redo_list_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_diagram_policy_enforcer_test_get_list() );
-        test_runner_run_suite( &runner, ctrl_classifier_policy_enforcer_test_get_list() );
-        test_runner_run_suite( &runner, pencil_layouter_test_get_list() );
-        test_runner_run_suite( &runner, pencil_diagram_maker_test_get_list() );
-        test_runner_run_suite( &runner, json_import_to_database_test_get_list() );
-        test_runner_run_suite( &runner, md_filter_test_get_list() );
-        test_runner_run_suite( &runner, io_export_model_traversal_test_get_list() );
+        /* data */
+        test_runner_run_suite( &runner, data_database_reader_test_get_suite() );
+        /* ctrl */
+        test_runner_run_suite( &runner, ctrl_controller_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_multi_step_changer_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_diagram_controller_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_classifier_controller_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_consistency_checker_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_undo_redo_list_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_diagram_policy_enforcer_test_get_suite() );
+        test_runner_run_suite( &runner, ctrl_classifier_policy_enforcer_test_get_suite() );
+        /* pencil */
+        test_runner_run_suite( &runner, pencil_layouter_test_get_suite() );
+        test_runner_run_suite( &runner, pencil_diagram_maker_test_get_suite() );
+        /* gui */
+        /* io */
+        test_runner_run_suite( &runner, io_importer_test_get_suite() );
+        test_runner_run_suite( &runner, md_filter_test_get_suite() );
+        test_runner_run_suite( &runner, io_export_model_traversal_test_get_suite() );
+        /* universal */
+        /* utf8stringbuf */
     }
 
     /* fetch failures */
