@@ -17,10 +17,10 @@ static void test_difference_2_stripe_candidates(void);
 static void test_difference_1_candidate(void);
 static void test_expand_4d(void);
 
-test_suite_t geometry_rectangle_test_get_list(void)
+test_suite_t geometry_rectangle_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "geometry_rectangle_test_get_list", &set_up, &tear_down );
+    test_suite_init( &result, "geometry_rectangle_test_get_suite", &set_up, &tear_down );
     test_suite_add_test_case( &result, "test_contain", &test_contain );
     test_suite_add_test_case( &result, "test_intersect", &test_intersect );
     test_suite_add_test_case( &result, "test_bounds", &test_bounds );
