@@ -10,10 +10,10 @@ static void test_expand_space(void);
 static void test_set_envelope_box(void);
 static void test_set_envelope_box_too_small(void);
 
-test_suite_t pencil_classifier_composer_test_get_list(void)
+test_suite_t pencil_classifier_composer_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "pencil_classifier_composer_test_get_list", &set_up, &tear_down );
+    test_suite_init( &result, "pencil_classifier_composer_test_get_suite", &set_up, &tear_down );
     test_suite_add_test_case( &result, "test_expand_space", &test_expand_space );
     test_suite_add_test_case( &result, "test_set_envelope_box", &test_set_envelope_box );
     test_suite_add_test_case( &result, "test_set_envelope_box_too_small", &test_set_envelope_box_too_small );
@@ -59,7 +59,7 @@ static void set_up(void)
         data_classifier_t data_classifier;
         data_diagramelement_t data_diagele;
 
-        const data_error_t err1
+        const u8_error_t err1
             = data_diagramelement_init( &data_diagele,
                                         17,  /* id */
                                         32,  /* diagram_id */
@@ -68,8 +68,8 @@ static void set_up(void)
                                         DATA_ROW_ID_VOID,
                                         "1ded6d32-cdea-43d8-931c-9459065f8944"
                                       );
-        TEST_ENVIRONMENT_ASSERT_EQUAL_INT( DATA_ERROR_NONE, err1 );
-        const data_error_t err2
+        TEST_ENVIRONMENT_ASSERT_EQUAL_INT( U8_ERROR_NONE, err1 );
+        const u8_error_t err2
             = data_classifier_init( &data_classifier,
                                     99,  /* id */
                                     DATA_CLASSIFIER_TYPE_CLASS,  /* main_type */
@@ -81,7 +81,7 @@ static void set_up(void)
                                     12000,  /* list_order */
                                     "94ad5563-3040-4f27-8e8b-d51ffc5ad4c8"
                                   );
-        TEST_ENVIRONMENT_ASSERT_EQUAL_INT( DATA_ERROR_NONE, err2 );
+        TEST_ENVIRONMENT_ASSERT_EQUAL_INT( U8_ERROR_NONE, err2 );
         data_visible_classifier_init( &data_vis_classifier, &data_classifier, &data_diagele );
         layout_visible_classifier_init( &layout_vis_classifier, &data_vis_classifier );
 
