@@ -1,9 +1,7 @@
 /* File: universal_memory_arena_test.c; Copyright and License: see below */
 
 #include "universal_memory_arena_test.h"
-#if 0
 #include "arena/universal_memory_arena.h"
-#endif
 #include "test_assert.h"
 #include <string.h>
 #include <stdint.h>
@@ -13,10 +11,10 @@ static void set_up(void);
 static void tear_down(void);
 static void test_alloc_blocks(void);
 
-test_suite_t universal_memory_arena_test_get_list(void)
+test_suite_t universal_memory_arena_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "universal_memory_arena_test_get_list", &set_up, &tear_down );
+    test_suite_init( &result, "universal_memory_arena_test_get_suite", &set_up, &tear_down );
     test_suite_add_test_case( &result, "test_alloc_blocks", &test_alloc_blocks );
     return result;
 }
@@ -31,7 +29,6 @@ static void tear_down(void)
 
 static void test_alloc_blocks(void)
 {
-#if 0
     char thirty_three[33];
 
     universal_memory_arena_t test_me;
@@ -42,15 +39,13 @@ static void test_alloc_blocks(void)
     err = universal_memory_arena_get_block( &test_me, 1, &block_1 );
     TEST_ASSERT_EQUAL_INT( 0, err );
     TEST_ASSERT( NULL != block_1 );
-    TEST_ASSERT_EQUAL_INT( 0, ((unsigned int)block_1) % sizeof(int) );
+    TEST_ASSERT( &(thirty_three[1]) == block_1 );
 
     void *block_2;
     err = universal_memory_arena_get_block( &test_me, 1, &block_2 );
     TEST_ASSERT_EQUAL_INT( 0, err );
     TEST_ASSERT( NULL != block_2 );
-    TEST_ASSERT_EQUAL_INT( 0, ((unsigned int)block_1) % sizeof(int) );
-
-    TEST_ASSERT_EQUAL_INT( sizeof(int), ((unsigned int)block_2)-((unsigned int)block_1) );
+    TEST_ASSERT( &(thirty_three[1+sizeof(int)]) == block_2 );
 
     universal_memory_arena_reset( &test_me );
 
@@ -58,7 +53,7 @@ static void test_alloc_blocks(void)
     err = universal_memory_arena_get_block( &test_me, 33-sizeof(int), &block_3 );
     TEST_ASSERT_EQUAL_INT( 0, err );
     TEST_ASSERT( NULL != block_3 );
-    TEST_ASSERT_EQUAL_INT( 0, ((unsigned int)block_3) % sizeof(int) );
+    TEST_ASSERT( &(thirty_three[1]) == block_3 );
 
     void *block_4;
     err = universal_memory_arena_get_block( &test_me, sizeof(int), &block_4 );
@@ -66,7 +61,6 @@ static void test_alloc_blocks(void)
     TEST_ASSERT( NULL == block_4 );
 
     universal_memory_arena_destroy( &test_me );
-#endif
 }
 
 
